<?php

namespace Etn_Pro\Core\Event;

use Exception;

defined( 'ABSPATH' ) || exit;

class Api_Event_Taxonomy extends \Etn\Base\Api_Handler {

    /**
     * define prefix and parameter patten
     *
     * @return void
     */
    public function config() {
        $this->prefix = 'event-taxonomy';
        $this->param  = ''; // /(?P<id>\w+)/
    }

    /**
     * Get event categories data through api
     *
     * @return array
     */
    public function get_categories() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;
        
        try{

            $terms = get_terms( array(
                'taxonomy' => 'etn_category',
                'hide_empty' => false,
            ) );
    
            if ( is_wp_error( $terms ) ) {
                return [
                    'status_code' => 409,
                    'messages'    => [__( 'Could not get categories', 'eventin-apro' )],
                    'content'     => $terms->get_error_message(),
                ];
            }
            
            return [
                'status_code' => 200,
                'messages'    => [
                    __( 'Success', 'eventin-apro' )
                ],
                'content'     => $terms,
            ];
        } catch( \Exception $e){
            return [
                'status_code' => 404,
                'messages'    => [__( 'Something went wrong! Try again!', 'eventin-apro' )],
                'content'     => $e->getMessage(),
            ];
        }
    }

    /**
     * Get event tags data through api
     *
     * @return array
     */
    public function get_tags() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;
        
        try{

            $terms = get_terms( array(
                'taxonomy' => 'etn_tags',
                'hide_empty' => false,
            ) );
    
            if ( is_wp_error( $terms ) ) {
                return [
                    'status_code' => 409,
                    'messages'    => [__( 'Could not get tags', 'eventin-apro' )],
                    'content'     => $terms->get_error_message(),
                ];
            }
            
            return [
                'status_code' => 200,
                'messages'    => [
                    __( 'Success', 'eventin-apro' )
                ],
                'content'     => $terms,
            ];

        } catch( \Exception $e ){
            return [
                'status_code' => 404,
                'messages'    => [__( 'Something went wrong! Try again!', 'eventin-apro' )],
                'content'     => $e->getMessage(),
            ];
        }
    }

}

new Api_Event_Taxonomy();