<?php

namespace Etn_Pro\Core\Event;

use Etn\Utils\Helper;

defined( 'ABSPATH' ) || exit;

class Api_Event extends \Etn\Base\Api_Handler {

    /**
     * define prefix and parameter patten
     *
     * @return void
     */
    public function config() {
        $this->prefix = 'events';
        $this->param  = ''; // /(?P<id>\w+)/
    }

    /**
     * save settings data through api
     *
     * @return array
     */
    public function post_create() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;

        $request_array = json_decode( $request->get_body(), true );

        $required_fields = [
            'post_author'  => '',
            'post_title'   => '',
            'post_content' => '',
        ];

        $required_fields_validation = $this->check_required_fields_exists( $required_fields, $request_array );

        if ( empty( $required_fields_validation['validation_code'] ) ) {
        // pass input field for checking empty value
        $inputs_field = [
            ['name' => 'post_author', 'required' => true, 'type' => 'number'],
            ['name' => 'post_title', 'required' => true, 'type' => 'text'],
            ['name' => 'post_content', 'required' => true, 'type' => 'text'],
        ];

        $validation = Helper::input_field_validation( $request_array, $inputs_field );

        if ( !empty( $validation['status_code'] ) && $validation['status_code'] == true ) {
            $input_data   = $validation['data'];
            $post_title   = $input_data['post_title'];
            $post_content = $input_data['post_content'];
            $post_author  = $input_data['post_author'];

            // insert event CPT
            $event_id = wp_insert_post( [
                'post_title'   => $post_title,
                'post_content' => $post_content,
                'post_author'  => $post_author,
                'post_type'    => 'etn',
                'post_status'  => 'publish',
                'menu_order'   => !empty($request_array['_etn_buddy_group_id']) ? $request_array['_etn_buddy_group_id'] : 0 ,
            ] );

            if ( !empty( $event_id ) && !is_wp_error( $event_id ) ) {
                $default_meta_fields = [
                    '_stock'         => 0,
                    '_price'         => 0,
                    '_sale_price'    => 0,
                    '_regular_price' => 0,
                ];

                foreach ( $default_meta_fields as $field_name => $field_value ) {
                    update_post_meta( $event_id, $field_name, $field_value );
                }

                wp_set_post_terms( $event_id, $request_array['etn_tags'], 'etn_tags' );
                wp_set_post_terms( $event_id, $request_array['etn_category'], 'etn_category' );

                $this->update_event_meta_fields( $event_id, $request_array );

                $status_code = 1;
                $messages[]  = esc_html__( 'Event created successfully', 'eventin-pro' );
            } else {
                return [
                    'status_code' => 409,
                    'messages'    => [esc_html__( 'Could not create event', 'eventin-pro' )],
                    'content'     => $event_id->get_error_message(),
                ];
            }

        } else {

                $status_code = $validation['status_code'];

                $messages    = $validation['messages'];

            }

        } else {

            $messages[] = $required_fields_validation['msg'];
        }

        // Sent event object as json response.
        if ( ! is_wp_error( $event_id ) ) {
            $content['event'] = $this->preapre_item( $event_id );
        }

        return [
            'status_code' => $status_code,
            'messages'    => $messages,
            'content'     => $content,
        ];
    }

    /**
     * update event data through api
     *
     * @return array
     */
    public function post_update() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;

        $request_array = json_decode( $request->get_body(), true );

        $required_fields = [
            'post_author'  => '',
            'post_title'   => '',
            'post_content' => '',
            'event_id'     => '',
        ];

        $required_fields_validation = $this->check_required_fields_exists( $required_fields, $request_array );

        if ( empty( $required_fields_validation['validation_code'] ) ) {
        // pass input field for checking empty value
        $inputs_field = [
            ['name' => 'post_author', 'required' => true, 'type' => 'number'],
            ['name' => 'post_title', 'required' => true, 'type' => 'text'],
            ['name' => 'post_content', 'required' => true, 'type' => 'text'],
            ['name' => 'event_id', 'required' => true, 'type' => 'number'],
        ];

        $validation = Helper::input_field_validation( $request_array, $inputs_field );

        if ( !empty( $validation['status_code'] ) && $validation['status_code'] == true ) {
        $input_data   = $validation['data'];
        $post_title   = $input_data['post_title'];
        $post_content = $input_data['post_content'];
        $post_author  = $input_data['post_author'];
        $event_id     = $input_data['event_id'];

        if ( !empty( $event_id ) ) {

            $event_id = wp_update_post( [
                'ID'           => $event_id,
                'post_title'   => $post_title,
                'post_content' => $post_content,
                'post_author'  => $post_author,
            ] );

            if ( !is_wp_error( $event_id ) ) {
                wp_set_post_terms( $event_id, $request_array['etn_tags'], 'etn_tags' );
                wp_set_post_terms( $event_id, $request_array['etn_category'], 'etn_category' );
                $this->update_event_meta_fields( $event_id, $request_array );
                $status_code = 1;
                $messages[]  = esc_html__( 'Event updated successfully', 'eventin-pro' );
            } else {
                return [
                    'status_code' => 409,
                    'messages'    => [esc_html__( 'Could not update event', 'eventin-pro' )],
                    'content'     => $event_id->get_error_message(),
                ];
            }

        }

        } else {

            $status_code = $validation['status_code'];

            $messages    = $validation['messages'];

        }

        } else {

            $messages[] = $required_fields_validation['msg'];

        }

        if ( ! is_wp_error( $event_id ) ) {
            $content['event'] = $this->preapre_item( $event_id );
        }

        return [

            'status_code' => $status_code,

            'messages'    => $messages,

            'content'     => $content,
                ];

    }

    /**
     * validate required fields are exist in request
     *
     * @param array $required_fields
     * @param array $request_array
     * @return array
     */
    public function check_required_fields_exists( $required_fields = [], $request_array = [] ) {
        $validation_code = 0;
        $msg             = '';

        $has_required_fields = ( 0 === count( array_diff_key( $required_fields, $request_array ) ) );

        if ( !$has_required_fields ) {
            $validation_code = 400;
            $msg             = esc_html__( 'Required fields are missing', 'eventin-pro' );
        }

        return [
            'validation_code' => $validation_code,
            'msg'             => $msg,
        ];
    }

    /**
     * update event specific meta data
     *
     * @param [type] $event_id
     * @return void
     */
    public function update_event_meta_fields( $event_id = null, $request_array = [] ) {
        $update_fields = [
            'etn_event_organizer',
            'etn_event_schedule',
            'etn_event_socials',

            'etn_event_logo',
            '_thumbnail_id',

            'event_timezone',
            'etn_start_time',
            'etn_end_time',
            'etn_start_date',
            'etn_end_date',
            'etn_registration_deadline',

            'etn_ticket_availability',
        ];

        foreach ( $update_fields as $index => $field_name ) {
            $field_value = isset( $request_array[$field_name] ) ? $request_array[$field_name] : '';
            update_post_meta( $event_id, $field_name, $field_value );
        }

        $field_name = 'etn_event_location';

        if ( isset( $request_array[$field_name] ) && !empty( $request_array[$field_name] ) ) {
            update_post_meta( $event_id, $field_name, $request_array[$field_name] );
            update_post_meta( $event_id, 'etn_event_location_type', 'existing_location' );
        }

        $field_name = 'banner_bg_image';

        if ( isset( $request_array[$field_name] ) && !empty( $request_array[$field_name] ) ) {
            update_post_meta( $event_id, $field_name, $request_array[$field_name] );
            update_post_meta( $event_id, 'etn_banner', 'on' );
            update_post_meta( $event_id, 'banner_bg_type', 'no' );
        }

        $field_name = 'etn_ticket_variations';

        if ( isset( $request_array[$field_name] ) ) {
            $ticket_variations_info    = Helper::get_ticket_variations_info( $event_id, $request_array[$field_name] );
            $ticket_variations         = $ticket_variations_info['ticket_variations'];
            $etn_total_created_tickets = $ticket_variations_info['etn_total_created_tickets'];

            $saved_ticket_variations = get_post_meta( $event_id, 'etn_ticket_variations', true );

            foreach ( $ticket_variations as $info_key => &$info_value ) {
                $info_value['etn_sold_tickets'] = isset( $saved_ticket_variations[$info_key]['etn_sold_tickets'] ) ? $saved_ticket_variations[$info_key]['etn_sold_tickets'] : 0;
            }

            update_post_meta( $event_id, $field_name, $ticket_variations );
            update_post_meta( $event_id, 'etn_total_avaiilable_tickets', $etn_total_created_tickets );
        }

    }

    public function get_timezone() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;

        $timezone_markup = wp_timezone_choice( '', get_user_locale() );

        if ( !empty( $timezone_markup ) ) {
            $status_code                = 1;
            $messages[]                 = esc_html__( 'Timezone retrieved successfully', 'eventin-pro' );
            $content['timezone_markup'] = $timezone_markup;
        }

        return [
            'status_code' => $status_code,
            'messages'    => $messages,
            'content'     => $content,
        ];
    }

    public function get_related_info() {
        $status_code = 0;
        $messages    = $content    = [];
        $request     = $this->request;

        $taxonomy_obj       = new \Etn_Pro\Core\Event\Api_Event_Taxonomy();
        $categories_info    = $taxonomy_obj->get_categories()['content'];
        $tags_info          = $taxonomy_obj->get_tags()['content'];

        $speaker_cat_info   = ( new \Etn_Pro\Core\Event\Api_Speaker_Taxonomy() )->get_categories()['content'];
        $schedule_info      = ( new \Etn_Pro\Core\Event\Api_Schedules() )->get_all()['content'];

        $timezone_info      = $this->get_timezone()['content']['timezone_markup'];

        $content['categories']          = $categories_info;
        $content['tags']                = $tags_info;
        $content['speaker_categories']  = $speaker_cat_info;
        $content['schedules']           = $schedule_info;
        $content['timezone_markup']     = $timezone_info;

        $status_code = 1;
        $messages[]  = esc_html__( 'All info retireved', 'eventin-pro' );

        return [
            'status_code' => $status_code,
            'messages'    => $messages,
            'content'     => $content,
        ];
    }

    /**
     * Prepare item for response
     *
     * @param   object  $event  [$event description]
     *
     * @return  [type]          [return description]
     */
    public function preapre_item( $event_id ) {
        /**
         * Event meta data
         */
        $event              = get_post( $event_id );
        $sold_tickets       = get_post_meta( $event_id, 'etn_total_sold_tickets', true );
        $avaiilable_tickets = get_post_meta( $event_id, 'etn_total_avaiilable_tickets', true );
        $start_date         = get_post_meta( $event_id, 'etn_start_date', true );
        $location           = get_post_meta( $event_id, 'etn_event_location', true );
        $permalink          = get_permalink( $event_id );
        $event_image        = wp_get_attachment_url( get_post_thumbnail_id( $event_id ) );
        

        /**
         * Get event data and prepare for response
         */
        return [
            'id'            => $event_id,
            'title'         => $event->post_title,
            'date'          => date_i18n( get_option( 'date_format' ), strtotime( $start_date ) ),
            'location'      => $location,
            'image'         => $event_image,
            'permalink'     => $permalink, 
            'availbe_seats' => intval( $avaiilable_tickets ),
            'booked_seats'  => intval( $sold_tickets ),
        ];
    }

}

new Api_Event();