<?php
namespace Etn_Pro\Core\Modules\Sells_Engine\Stripe\Orders;
use Etn_Pro\Utils\Helper;

defined('ABSPATH') || exit;

if ( ! class_exists( 'WP_List_Table' )){
    require_once ABSPATH . 'wp-admin/inclueds/class-wp-list-table.php';
}

class Orders_Report extends \WP_List_Table{

    public $singular_name;
    public $plural_name;
    public $id = '';
    
    /**
     * Show list
     */
    function __construct($all_data_of_table){

        $this->singular_name = $all_data_of_table['singular_name'];
        $this->plural_name   = $all_data_of_table['plural_name'];

        parent::__construct( [
            'singular' => $this->singular_name ,
            'plural'   => $this->plural_name ,
            'ajax'     => true ,
        ]);
    }
    
    /**
     * Get column header function
     */
    public function get_columns(){

        $country_currency = \Etn_Pro\Utils\Helper::retrieve_country_currency();
        return [
            'order_id'        => esc_html__( 'Order ID',  'eventin-pro' ),
            'invoice'         => esc_html__( 'Invoice',  'eventin-pro' ),
            'puchaser_info'   => esc_html__( 'Purchaser',  'eventin-pro' ),
            'email'           => esc_html__( 'Email',  'eventin-pro' ),
            'payment_type'    => esc_html__( 'Payment Gateway',  'eventin-pro' ),
            'event_amount'    => esc_html__( 'Amount',  'eventin-pro' ) . ' [' . esc_html( $country_currency['currency'] ) . ']',
            'status'          => esc_html__( 'Status',  'eventin-pro' ),
            'date_time'       => esc_html__( 'Date',  'eventin-pro' ),
            'details'         => esc_html__( 'Action',  'eventin-pro' ),
        ];
    }

    /**
     * Display all row function
     */
    protected function column_default( $item , $column_name ){
        switch( $column_name ) { 
            case $column_name:
                return $item[ $column_name ];
            default:
                isset( $item[ $column_name ] ) ? $item[ $column_name ]: '';
            break;
          }
    }

    /**
     * purchaser information
     */
    protected function column_puchaser_info( $item ){
        $stripe_order_id = $item['form_id'];
        $first_name      = get_post_meta( $stripe_order_id, '_billing_first_name', true );
        $last_name       = get_post_meta( $stripe_order_id, '_billing_last_name', true );
        return $first_name . ' ' . $last_name;
    }

    /**
     * Show order id link
     */
    public function column_order_id( $item ){
        $order_url      = admin_url( 'admin.php?page=etn_stripe_orders_report&order_id=' . $item['form_id'] );
        $order_url_href = "<a href='". $order_url ."' target='_blank'>". $item['form_id'] ."</a>";

        return $order_url_href;
    }

    /**
     * Show order deatils link
     */
    public function column_details( $item ){
        $order_details_url = admin_url( 'admin.php?page=etn_stripe_orders_report&order_id=' . $item['form_id'] );
        ob_start();
        ?>
        <div class="etn-event-report-action">
            <div class="etn-event-report-view-report"><a target="_blank" class="etn-btn-text btn-primary" href='<?php echo esc_url( $order_details_url ) ;?>'> <?php echo esc_html__('Details', 'eventin-pro') ?></a></div>
        </div>
        <?php
        return ob_get_clean();
    }
   
    /**
     * Main query and show function
     */
    
    public function preparing_items(){
        $per_page = 20;
        $column   = $this->get_columns();
        $hidden   = [];
        $this->_column_headers = [ $column , $hidden ];
        $current_page = $this->get_pagenum();
        $offset       = ( $current_page - 1 ) * $per_page;

        $args = [];
        if ( isset( $_REQUEST['orderby']) && isset( $_REQUEST['order']) ){
            $args['orderby'] = sanitize_text_field( $_REQUEST['orderby'] );
            $args['order']   = sanitize_text_field( $_REQUEST['order'] );
        } 
        // search result
        $args['limit']          = $per_page;
        $args['offset']         = $offset;
        $order_history       = \Etn_Pro\Core\Action::instance()->order_history( $args );

        $this->set_pagination_args( [
            'total_items'   => $order_history['count'],
            'per_page'      => $per_page,
        ] );
        $this->items =  $order_history['data'];
    }

}