<?php

use Etn_Pro\Core\Webhook\Webhook;

$webhook_id = ! empty( $webhook_id ) ? $webhook_id : 0;
$webhook    = new Webhook( $webhook_id );
$is_edit    = $webhook->get_id() > 0 ? true: false;
$class      = $is_edit ? 'etn-webhook-item' : 'etn-add-new-webhook';
$form_class = $is_edit ? 'edit' : 'etn-add-webhook';

$topics = [
    'event.created'    => __( 'Event Create', 'eventin-pro' ),
    'event.updated'    => __( 'Event Update', 'eventin-pro' ),
    'event.deleted'    => __( 'Event Delete', 'eventin-pro' ),
    'event.restored'   => __( 'Event Restore' ),
    'speaker.created'  => __( 'Speaker Create', 'eventin-pro' ),
    'speaker.updated'  => __( 'Speaker Update', 'eventin-pro' ),
    'speaker.deleted'  => __( 'Speaker Delete', 'eventin-pro' ),
    'speaker.restored' => __( 'Speaker Restore', 'eventin-pro' ),
];

$statuses = [
    'active'    =>  __( 'Active', 'eventin-pro' ),
    'pending'   =>  __( 'Pending', 'eventin-pro' ),
    'disable'   =>  __( 'Disable', 'eventin-pro' ),
]
?>

<div class="attr-form-group etn-label-item etn-label-top <?php echo $class; ?>">
    <?php if ( $is_edit ): ?>
        <div class="etn-label etn-webhook-title">
            <label><?php echo esc_html( $webhook->get_name() ); ?></label>
            <div class="etn-desc mb-2"><?php echo esc_html( $webhook->get_description() ); ?></div>
        </div>
        <div class="etn-meta">
            <button class="etn-btn-close webhook-close-btn">
                <span class="dashicons dashicons-no-alt"></span>
            </button>
        </div>
    <?php else: ?>
        <div class="new-item-head">
            <div class="attr-form-group">
                <p class="etn-desc etn-mb-2">
                    <?php echo esc_html__('Specify the domain where you want to use the webhook.','eventin-pro'); ?>
                </p>
                <button class="etn-btn-text" id="add-new-webhook"><?php esc_html_e( 'Add New', 'eventin-pro' ); ?></button>
            </div>
        </div>
    <?php endif; ?>
    <div class="etn-webhook-item-content <?php echo esc_attr( $form_class ); ?>">
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Name', 'eventin-pro' );?></label>
                <div class="etn-desc"><?php esc_html_e( 'User friendly name for webhook', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <input 
                    type="text" 
                    name="webhook_name" 
                    value="<?php echo esc_attr( $webhook->get_name() ); ?>" 
                    class="etn-setting-input attr-form-control etn-recaptcha-secret-key" placeholder="<?php esc_attr_e( 'Webhook Name', 'eventin-pro' ); ?>"
                >
            </div>
        </div>
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Status', 'eventin-pro' ); ?></label>
                <div class="etn-desc"><?php esc_html_e( 'Webhook Status', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <select name="webhook_status" class="etn-setting-input attr-form-control etn-settings-select">
                    <option value=""><?php esc_html_e( 'Seelect', 'eventin-pro' ); ?></option>
                    <?php foreach( $statuses as $stat_key => $status): ?>
                        <option 
                            value="<?php echo esc_attr( $stat_key ); ?>"
                            <?php echo $stat_key == $webhook->get_status() ? 'selected' : ''; ?>
                        ><?php echo esc_html( $status ); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Topic', 'eventin-pro' ); ?></label>
                <div class="etn-desc"><?php esc_html_e( 'Webhook Topic', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <select name="webhook_topic" class="etn-setting-input attr-form-control etn-settings-select">
                    <option value=""><?php esc_html_e( 'Select Topic', 'eventin-pro' ); ?></option>
                    <?php foreach( $topics as $topic_key => $topic ): ?>
                        <option 
                            value="<?php echo esc_attr( $topic_key ); ?>"
                            <?php echo $topic_key == $webhook->get_topic() ? 'selected' : '' ?> 
                        ><?php echo esc_html( $topic ); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div> 
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Delivary URL', 'eventin-pro' ); ?></label>
                <div class="etn-desc"><?php esc_html_e( 'User friendly name for webhook', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <input 
                    type="text" 
                    name="webhook_delivery_url" 
                    value="<?php echo esc_attr( $webhook->get_delivery_url() ); ?>" 
                    class="etn-setting-input attr-form-control etn-recaptcha-secret-key" placeholder="<?php esc_attr_e( 'Webhook Delivery URL', 'eventin-pro' ); ?>"
                >
            </div>
        </div>
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Secrete', 'eventin-pro' ); ?></label>
                <div class="etn-desc"><?php esc_html_e( 'Webhook Secrete', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <input 
                    type="text" 
                    name="webhook_secrete" 
                    value="<?php echo esc_attr( $webhook->get_secrete() ); ?>" 
                    class="etn-setting-input attr-form-control etn-recaptcha-secret-key" placeholder="<?php esc_attr_e( 'Webhook Secrete', 'eventin-pro' ); ?>"
                >
            </div>
        </div> 
        <div class="attr-form-group etn-label-item">
            <div class="etn-label">
                <label><?php esc_html_e( 'Description', 'eventin-pro' ); ?></label>
                <div class="etn-desc"><?php esc_html_e( 'Webhook Description', 'eventin-pro' ); ?></div>

            </div>
            <div class="etn-meta">
                <textarea 
                    name="webhook_description"
                    placeholder="<?php esc_attr_e( 'Webhook description', 'eventin-pro' ); ?>"
                    class="etn-setting-input attr-form-control" 
                ><?php echo esc_html( $webhook->get_description() ); ?></textarea>
            </div>
        </div>  
        <div class="attr-form-group etn-text-right etn-mt-3">
            <input type="hidden" name="webhook_id" value="<?php echo esc_attr( $webhook->get_id() ); ?>">
            <button class="etn-btn-text save-webhook-btn"><?php esc_html_e( 'Save Changes', 'eventin-pro' ); ?></button>
            <button class="etn-btn-text cancel-webhook-btn"><?php esc_html_e( 'Cancel', 'eventin-pro' ); ?></button>
        </div>
    </div>
</div>
