import { Button, Col, Input, Modal, Row, Select } from "antd";
import React, { useContext } from "react";
import EventContext from "../../context/EventContext";
const { Option } = Select;
const { __ } = wp.i18n;


function AttendeeEditModal({
  handleOk,
  hideModal,
  okText,
  cancelText,
  title,
  icon,
}) {

  const { state, onChangeFormData } = useContext(EventContext);
  const { show_attendee_edit_modal, attendeeToUpdate, btn_loader = false } = state;

/**
 * Handler for set and track Attendee data to UPDATE
 * @param {String} name Name of the field
 * @param {any} value Value of the field
 */
  const handleInputChange = (name, value) => {
    let _attendeeToUpdate = { ...attendeeToUpdate }
    _attendeeToUpdate[name] = value;
    onChangeFormData('attendeeToUpdate', _attendeeToUpdate)
  };


  return (
    <div className="etn-attendee-update-modal">
      <Modal
        visible={show_attendee_edit_modal}
        onOk={handleOk}
        onCancel={hideModal}
        wrapClassName={'etn-edit-attendee-modal'}
        // okText={okText}
        // cancelText={cancelText}
        footer={[
          <Button type="primary" block style={{ backgroundColor: '#5D5DFF', color: '#ffffff', borderRadius: '4px' }} size="large" key="update" onClick={handleOk} loading={btn_loader}>
            {__("Update details", 'eventin-pro')}
          </Button>,

        ]}
      >
        <Row gutter={[20, 20]} >
          <Col>
            <div>{__("Ticket status", 'eventin-pro')}</div>
          </Col>
          <Col>
            <Select
              value={attendeeToUpdate?.etn_attendeee_ticket_status}
              style={{
                width: 120,
              }}
              onChange={(value, option) => {
                const name = option.name;
                handleInputChange(name, value)
              }}
            >
              <Option value="used" name="etn_attendeee_ticket_status">{__("Used", 'eventin-pro')}</Option>
              <Option value="unused" name="etn_attendeee_ticket_status">{__("Unused", 'eventin-pro')}</Option>
            </Select>
          </Col>
        </Row>
        <Row gutter={[20, 20]}>
          <Col>
            <div>{__("Payment status", 'eventin-pro')}</div>
          </Col>
          <Col>
            {" "}
            <Select
              value={attendeeToUpdate?.etn_status}
              style={{
                width: 120,
              }}
              onChange={(value, option) => {
                const name = option.name;
                handleInputChange(name, value)
              }}
            >
              <Option value="success" name="etn_status">{__("Success", 'eventin-pro')}</Option>
              <Option value="failed" name="etn_status">{__("Failed", 'eventin-pro')}</Option>
            </Select>
          </Col>
        </Row>
        <Row gutter={[20, 20]}>
          <Col >
            <div>{__("Attendee name", 'eventin-pro')}</div>
          </Col>
          <Col>
            <Input placeholder="Attendee name" name="etn_name" value={attendeeToUpdate?.etn_name} onChange={(e) => {
              const val = e.target.value;
              const name = e.target.name;
              handleInputChange(name, val)
            }} />
          </Col>
        </Row>
        <Row gutter={[20, 20]}>
          <Col>
            <div>{__("Attendee e-mail", 'eventin-pro')}</div>
          </Col>
          <Col>
            <Input placeholder={__("Attendee e-mail", 'eventin-pro')} name="etn_email" value={attendeeToUpdate?.etn_email} onChange={(e) => {
              const val = e.target.value;
              const name = e.target.name;
              handleInputChange(name, val)
            }} size='small' />
          </Col>
        </Row>
        {/* <Row gutter={[20, 20]}>
          <Col>
          <div>Attendee phone</div>
          </Col>
          <Col>
          <Input placeholder="Attendee phone" name="etn_phone" defaultValue={attendeeToUpdate?.etn_phone} onChange={(e) => {
            const val = e.target.value;
            const name = e.target.name;
            handleInputChange(name, val)
          }} size='small' />
          </Col>
        </Row> */}


      </Modal>
    </div>
  );
}

export default AttendeeEditModal;
