import { useEffect, useContext, useState } from "react";
import AttendeeTable from "./attendeeTable";
// import "antd/dist/antd.css";
import { get_attendees_by_event_id } from "../../apiEndpoints/endPoints";
import EventContext from "../../context/EventContext";
import Spinner from "../common/Spinner";
const { __ } = wp.i18n;

function AttendeeList() {
  const [loading, setLoading] = useState(false);

  const { state, onChangeFormData } = useContext(EventContext);
  const { paged, posts_per_page, top_nav_menu_active } = state;

  /**
   * Handler for GET Attendee by ID
   * @param {String} url Api endpoint
   * @param {Object} options options for Request if any
   * @returns Object consist of {Attendee, total count}
   */
  const getAttendeesByEventId = async (url, options) => {
    setLoading(true);
    const res = await fetch(url).catch((err) => {
      console.log("error", err);
      setLoading(false);
    });
    const data = await res.json();
    const { content: attendees, count } = data;

    return { attendees, count };
  };

  useEffect(async () => {
    const hash = window.location.hash;
    let _arrHash = hash.split("?");
    _arrHash = _arrHash[1].split("=")[1];

    let eventId = _arrHash ? _arrHash : "";
    onChangeFormData("event_id", eventId);
    // if(eventId){
    const url = `${get_attendees_by_event_id}?event=${eventId}&posts_per_page=${posts_per_page}&paged=${paged}`;
    const { attendees, count } = await getAttendeesByEventId(url, null);
    setLoading(false);
    onChangeFormData("etn_event_attendees", attendees);
    onChangeFormData("etn_event_attendees_count", count);
    // }
  }, []);

  return (
    <>
      {loading ? (
        <Spinner
          tip={__("Loading...", "eventin-pro")}
          msg={__("Please Wait.", "eventin-pro")}
          desc={__("Loader will vanish after all data load.", "eventin-pro")}
          type={"info"}
          size={"large"}
          wrapperClassName={"ent-mltv-spinner-wrapper"}
        />
      ) : (
        <>
          <div className="etn-mltv-event-attendee-list">
            {<AttendeeTable />}
          </div>
        </>
      )}
    </>
  );
}

export default AttendeeList;
