import { useContext, useState, useEffect } from "react";
import {
  Button,
  Checkbox,
  Dropdown,
  Menu,
  notification,
  Popconfirm,
  Space,
  Table,
  Tag,
} from "antd";
import EventContext from "../../context/EventContext";
import TableHeader from "./TableHeader";
import ConfirmModal from "../common/ConfirmModal";
import { base_url, delete_attendee_by_ids, get_attendees_by_event_id, update_attendee_by_id } from "../../apiEndpoints/endPoints";
import { openNotification } from "../../helpers/helper";
import AttendeeEditModal from "./AttendeeEditModal";
import TicketStatusCheck from "./TicketStatusCheck";
const { __ } = wp.i18n;

function AttendeeTable() {
  const [attendeeToDelete, setAttendeeToDelete] = useState(null);
  const [attendeeToEdit, setAttendeeToEdit] = useState(null);
  const [loading, setLoading] = useState(false)

  const { state, onChangeFormData, onPageChangeHandler, onAttendeeUpdateHandler } =
    useContext(EventContext);
  const {
    etn_event_attendees,
    etn_event_attendees_count,
    attendeeToUpdate,
    event_id,
    paged,
    posts_per_page,
    clicked_event
  } = state;


  function createMarkup(text) {
    return { __html: text };
  }

  const onClick = ({ key }) => {
    if (key == 'edit_attendee') {
      // onChangeFormData('top_nav_menu_active', 'key')
      onChangeFormData("show_attendee_edit_modal", true);
      onChangeFormData("attendeeToUpdate", attendeeToEdit)
    }
    if (key == 'delete_attendee') {
      //delete event.
      onChangeFormData("show_modal", true);


    }

  };

  const menu = (
    <Menu
      onClick={onClick}
      items={[
        {
          key: 'edit_attendee',
          label: 'Edit attendee',
        },
        {
          key: 'delete_attendee',
          label: 'Delete attendee',
          className: 'etn-item-delete-style'
        },
      ]}
    />
  );




  const columns = [
    {
      title: __("Ticket ID", 'eventin-pro'),
      dataIndex: "etn_unique_ticket_id",
      key: "etn_unique_ticket_id",
    },
    {
      title: "Name",
      dataIndex: "etn_name",
      key: "etn_name",
      render: (text) => text,
    },
    {
      title: "Email",
      dataIndex: "etn_email",
      key: "etn_email",
      render: (text) => text,
    },
    // {
    //   title: "Phone",
    //   dataIndex: "etn_phone",
    //   key: "etn_phone",
    //   render: (text) => text,
    // },
    {
      title: "Payment status",
      dataIndex: "etn_status",
      key: "etn_status",
      responsive: ['md'],
      render: (text) => {
        return (
          <div
            style={{
              color: text?.toLowerCase() == "success" ? "#02BB8E" : "#E8133A",
            }}
            className="etn-front-end-attendee-payment-status"
            dangerouslySetInnerHTML={{ __html: text }}
          ></div>
        );
      },
    },
    {
      title: "Ticket status",
      dataIndex: "etn_attendeee_ticket_status",
      key: "etn_attendeee_ticket_status",
      render: (text, record) => {
        return (
          <TicketStatusCheck
            text={text}
            attendee={record?.ID}
            attendeeData={record}
            ticket={record?.etn_unique_ticket_id}
          />
        );
      },
    },
    {
      title: "Action",
      key: "action",
      render: (_, record) => {
        return (
          <div className="etn-frontend-action-btns">
            <Button
              href={`${base_url}/wp-admin/etn-attendee?etn_action=download_ticket&attendee_id=${record?.ID}&etn_info_edit_token=${record?.etn_info_edit_token}`}
              target="_blank"
              className="etn-ticket-button"
            >
              Ticket
            </Button>

            <Dropdown overlay={menu} placement="bottomRight" trigger={["click"]}>
              <Button
                className="etn-fend-dropdown-trigger"
                onClick={() => {
                  setAttendeeToEdit(record)
                  setAttendeeToDelete(record?.ID)
                }
                }>...</Button>
            </Dropdown>

          </div>
        );
      },
    },
  ];

  const handleOk = async () => {
    const url = `${delete_attendee_by_ids}?ids=${attendeeToDelete}`;
    fetch(url, {
      method: "DELETE",
    })
      .then(async (res) => {
        const _res = await res.json();
        handleResponse(_res);
      })
      .catch((err) => {
        onChangeFormData("show_modal", false);
        openNotification(
          notification,
          "error",
          __("Delete!", "eventin-pro"),
          __("Something went wrong!", "eventin-pro")
        );
      });
  };

  const handleResponse = (res) => {
    onChangeFormData("show_modal", false);
    if (res?.status_code == 200) {
      const _etn_event_attendees = [...etn_event_attendees].filter(
        (attendee) => attendee?.ID !== attendeeToDelete
      );
      onChangeFormData("etn_event_attendees", _etn_event_attendees);
      openNotification(
        notification,
        "success",
        __("Deleted!", "eventin-pro"),
        __(res?.messages?.success, "eventin-pro")
      );
    } else {
      openNotification(
        notification,
        "error",
        __("Delete!", "eventin-pro"),
        __(res?.messages?.error, "eventin-pro")
      );
    }
  };

  const hideModal = () => {
    onChangeFormData("show_modal", false);
  };

  const handleUpdate = () => {
    if (attendeeToUpdate) {
      onChangeFormData("btn_loader", true);
      onAttendeeUpdateHandler(attendeeToUpdate);
    }
  };

  return (
    <>
      <ConfirmModal
        handleOk={handleOk}
        hideModal={hideModal}
        okText={ __("Delete",'eventin-pro')}
        cancelText={__("Cancel",'eventin-pro')}
        title={__("Are you sure you want to delete this item?",'eventin-pro')}
        icon={false}
      />
      <AttendeeEditModal
        handleOk={handleUpdate}
        hideModal={() => {
          onChangeFormData("show_attendee_edit_modal", false);
          onChangeFormData("attendeeToUpdate", null);

        }}
        okText={__("Update details",'eventin-pro')}
        cancelText={__("Cancel",'eventin-pro')}
        title={__("Edit attendee",'eventin-pro')}
        icon={false}
      />
      <TableHeader
        heading={__("Attendees List",'eventin-pro')}
        isScanner={true}
        eventId={event_id}
      />
      <Table
        loading={loading}
        columns={columns}
        dataSource={[...etn_event_attendees]}
        className={'etn-frontend-attendee-table'}
        pagination={{
          total: etn_event_attendees_count,
          defaultPageSize: posts_per_page,
          showSizeChanger: true,
          pageSizeOptions: ["20", "50", "100"],
          className: ['etn-ant-pagination'],
          onChange: (page_no, pageSize) => {
            const _pageSize = pageSize ? pageSize : posts_per_page;
            onPageChangeHandler({ event_id, page_no, _pageSize });
          },
        }}
        rowKey={(record) => {
          return record.ID
        }}
      />
    </>
  );
}

export default AttendeeTable;
