import { Button, Col, Form, Input, Row } from "antd";
import React, { useContext } from "react";
import EventContext from "../../context/EventContext";
import TimePicker from "./TimePicker";
const { __ } = wp.i18n;

function CreateSchedule() {
  const schedule = {
    title: "",
    topic: "",
    start_time: "",
    end_time: "",
  };

  const { state, onChangeFormData } = useContext(EventContext);
  const { etn_event_schedule_title, etn_event_schedule_topic, etn_schedules } =
    state;

    // configuration for disable time(second)
  const disabledTime =(_, type) => {
    const range = (start, end) => {
      const result = [];

      for (let i = start; i < end; i++) {
        result.push(i);
      }

      return result;
    };
    if (type === "start") {
      return {
        disabledHours: () => range(0, 0).splice(4, 20),
        disabledMinutes: () => range(0, 0),
        disabledSeconds: () => [0, 10],
      };
    }

    return {
      disabledHours: () => range(0, 0).splice(4, 20),
      disabledMinutes: () => range(0, 0),
      disabledSeconds: () => [0, 59],
    };
  }

  return (
    <div className="etn-front-end-create-schedule">
      {etn_schedules?.map((scheduleItem, i) => {
        return (
          <div className="etn-front-end-create-schedule-wrapper" key={`etn-schedule-create-${i}`}>
            {i > 0 && <Row>
              <Col>
              <Button
                  className="etn-close-button"
                  type="danger"
                  size={"small"}
                  onClick={() => {
                    onChangeFormData(
                      "etn_schedules",
                      etn_schedules.filter((item, index) => i !== index)
                    );
                  }}
                >
                  X
                </Button>
              </Col>
            </Row>}
            <Row gutter={[12, 12]}>
              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("Schedule title", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <Input
                    type={"text"}
                    value={
                      etn_event_schedule_title ? etn_event_schedule_title : ""
                    }
                    onChange={(e) => [
                      onChangeFormData(
                        "etn_event_schedule_title",
                        e.target.value
                      ),
                    ]}
                    size="small"
                    placeholder={__("Enter title", "eventin-pro")}
                  />
                </Form.Item>
              </Col>

              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("Topic", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <Input
                    type={"text"}
                    value={
                      etn_event_schedule_topic ? etn_event_schedule_topic : ""
                    }
                    onChange={(e) => [
                      onChangeFormData(
                        "etn_event_schedule_topic",
                        e.target.value
                      ),
                    ]}
                    size="small"
                    placeholder={__("Enter topic", "eventin-pro")}
                  />
                </Form.Item>
              </Col>
            </Row>

            <Row gutter={[12, 12]}>
              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("Start time", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <TimePicker disabledTime={disabledTime} />
                </Form.Item>
              </Col>

              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("End time", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <TimePicker disabledTime={disabledTime} />
                </Form.Item>
              </Col>
            </Row>
            
          </div>
        );
      })}
      <Row gutter={[12, 12]}>
              <Col xs={24} sm={24} md={24}>
                <Button
                  onClick={() => {
                    onChangeFormData("etn_schedules", [
                      ...etn_schedules,
                      schedule,
                    ]);
                  }}
                >
                  {__("Add More Schedule", "eventin-pro")}
                </Button>
              </Col>
            </Row>
    </div>
  );
}

export default CreateSchedule;
