import { Button, Col, Form, Input, notification, Row } from "antd";
import React, { useContext, useState, useEffect } from "react";
import { get_related_info, speakers_api } from "../../apiEndpoints/endPoints";
import EventContext from "../../context/EventContext";
import { openNotification } from "../../helpers/helper";
import IconModal from "./IconModal";
import ImgPreview from "./ImgPreview";
import SelectWithCustomBtn from "./SelectWithCustomBtn";
import Spinner from "./Spinner";
import TimePicker from "./TimePicker";
import UploadButton from "./UploadButton";
import { etn_speaker_socials as socials } from "../../stores/store";
import SocialRepeater from "./SocaialRepeater";
const { __ } = wp.i18n;
const { TextArea } = Input;

function CreateSpeaker({ id, editMode }) {
  const links = {
    icon: "",
    etn_social_title: "",
    etn_social_url: "",
  };
  const speaker = {
    name: "",
    designation: "",
    socials: [{ ...links }],
  };

  const [iconModal, setModal] = useState(false);
  const [socialLinkIndex, setSocialLinkIndex] = useState(null);
  const [speakerIndex, setSpeakerIndex] = useState(null);

  const setIconModal = (
    modalStatue,
    socialLinkIndex = null,
    speakerIndex = null
  ) => {
    setModal(modalStatue);
    setSocialLinkIndex(socialLinkIndex);
    setSpeakerIndex(speakerIndex ? speakerIndex : speakerIndex);
  };

  const {
    state,
    onChangeFormData,
    setCategoryData,
    setTagsData,
    setOrganizerData,
    setScheduleData,
    setTimeZoneData,
    onCreateSpeaker,
  } = useContext(EventContext);
  const {
    etn_event_schedule_title,
    etn_event_schedule_topic,
    etn_speaker_socials,
    etn_speaker_create,
    etn_event_speaker_cat,
    organizerData,
    isLoading,
    company_logo_url,
  } = state;

  /**
   * Handler for image uploading
   * @param {String} name Name of the image field
   */
  const handleWpUploader = ({ name, value }) => {
    const custom_uploader = wp
      .media({
        title: "Insert image",
        library: {
          type: "image",
        },
        button: {
          text: "Use this image", // button label text
        },
        // multiple,
      })
      .on("select", function (sele) {
        const attachment = custom_uploader
          .state()
          .get("selection")
          .first()
          .toJSON();
        let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));
        // onChangeSpeakerData(`${name}_url`, attachment.url);
        // onChangeSpeakerData(name, attachment.id);
        _etn_speaker[value] = attachment.url;
        _etn_speaker[name] = attachment.id;
        onChangeFormData("etn_speaker_create", _etn_speaker);
      })
      .open();
  };

  /**
   * Handler for set social icon
   * @param {String} value value of the field
   * @param {String} name Name of the field
   */
  const getIcon = (value, name) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));
    let _socialLinks = _etn_speaker.socials;
    _socialLinks[socialLinkIndex] = {
      ..._socialLinks[socialLinkIndex],
      [name]: value,
    };
    _etn_speaker.socials = _socialLinks;
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for format and set social icon data
   * @param {String} value value of the field
   * @param {String} name Name of the field
   */
  const setSocialData = (value, name, i) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));

    let _socialLinks = _etn_speaker.socials;
    _socialLinks[i] = { ..._socialLinks[i], [name]: value };
    _etn_speaker.socials = _socialLinks;
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for adding another social to the repeater field
   * @param {Object} etn_speaker_create Another social objec for repeater
   */
  const addMoreSocial = (etn_speaker_create) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));

    let _socialLinks = _etn_speaker.socials;
    _socialLinks = [..._socialLinks, links];
    _etn_speaker.socials = _socialLinks;
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for removing one social from the repeater field
   * @param {Number} linkIndex Index of social to remove form the repeater
   */
  const removeSocial = (linkIndex) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));

    let _socialLinks = _etn_speaker.socials;

    if ([..._socialLinks].length == 1) {
      _socialLinks = [links];
    } else {
      _socialLinks = [..._socialLinks].filter(
        (sLink, index) => linkIndex != index
      );
    }

    _etn_speaker.socials = _socialLinks;
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for onChange speaker data
   * @param {String} fieldName Name of the field for speaker
   * @param {String} value Value of the field for speaker
   */
  const onChangeSpeakerData = (fieldName, value) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));
    _etn_speaker[fieldName] = value;
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for clear the speaker logo id and url
   * @param {any} value Anything(id, url) for speaker logo
   */
  const onChangeSpeakerLogoData = (value) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));
    _etn_speaker["company_logo_url"] = "";
    _etn_speaker["company_logo"] = "";
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };
  /**
   * Handler for clear the speaker profile id and url
   * @param {any} value Anything(id, url) for speaker logo
   */
  const onChangeSpeakerProfileData = (value) => {
    let _etn_speaker = JSON.parse(JSON.stringify(etn_speaker_create));
    _etn_speaker["image"] = "";
    _etn_speaker["thumbnail_id"] = "";
    onChangeFormData("etn_speaker_create", _etn_speaker);
  };

  /**
   * Handler for get speaker data from dropdown
   * @param {*} value
   * @param {*} propName
   * @param {*} name
   */
  const getData = (value, propName, name) => {
    const category = [...organizerData].filter((item) =>
      [...value].includes(item["term_id"])
    );

    const ids = [...value].map((item) => {
      return item[propName];
    });
    // onChangeSpeakerData(`${name}_ids`, ids);
    onChangeSpeakerData(`${name}_ids`, value.toString());
    onChangeSpeakerData(`${name}`, value);
  };

  useEffect(async () => {
    // onChangeFormData("isLoading", true);
    try {
      if (id) {
        const res = await fetch(`${speakers_api}?id=${id}`);
        let data = await res.json();
        if (!Array.isArray(data?.socials)) {
          data = { ...data, socials: socials };
        }
        onChangeFormData("etn_speaker_create", data);
      }

      // calling get_related_info api to get all other data related to event.
      const _res = await fetch(get_related_info);
      const _data = await _res.json();
      // onChangeFormData("isLoading", false);

      const {
        categories,
        schedules,
        speaker_categories,
        tags,
        timezone_markup,
      } = _data.content;

      // setting all other data related to event to context.
      setCategoryData(categories);
      setTagsData(tags);
      setOrganizerData(speaker_categories);
      setScheduleData(schedules);
      setTimeZoneData(timezone_markup);
    } catch (error) {
      onChangeFormData("isLoading", false);

      console.log("error: ", error);
    }
  }, []);

  /**
   * Handler for CREATE Speaker
   * @returns Nothing
   */
  const createSpeaker = () => {
    window.scrollTo({ top: 0, behavior: "smooth" });

    // cannot submit when post title or content is empty.
    if (etn_speaker_create?.name?.trim() == "" || !etn_speaker_create?.name) {
      return openNotification(
        notification,
        "error",
        __("Input missing!", "eventin-pro"),
        __("Speaker name should not empty!", "eventin-pro")
      );
    }
    // Context provider method for submitting speaker data to backend
    onCreateSpeaker(etn_speaker_create, id);
  };

  /**
   * Handler for determine if we want to create speaker category
   * @param {Object} e Event Object
   * @param {String} name Name of the field
   */
  const addSpeakerCat = (e, name) => {
    e.preventDefault();
    onChangeFormData(`${name}_create`, true);
    onChangeFormData(`${name}`, []);
    onChangeFormData(`setOpen`, false);
  };

  if (isLoading) {
    return (
      <Spinner
        tip={__("Loading...", "eventin-pro")}
        msg={__("Please Wait.", "eventin-pro")}
        desc={__("Loader will vanish after all data load.", "eventin-pro")}
        type={"info"}
        size={"large"}
        wrapperClassName={"ent-mltv-spinner-wrapper"}
      />
    );
  }

  return (
    <div className="etn-front-end-create-speaker ">
      <IconModal
        isModalVisible={iconModal}
        setIsModalVisible={(modalStatue, socialLinkIndex) => {
          setIconModal(modalStatue, socialLinkIndex, null);
        }}
        getIcon={getIcon}
        fieldName={"icon"}
      />

      <div
        className="etn-frontend-speaker-item"
        style={{
          border: "1px solid #ddd",
          borderRadius: "8px",
          padding: "35px",
          margin: "10px 0",
          background: "#ffffff",
        }}
      >
        <Form
          name="speaker_create_form"
          layout="vertical"
          labelCol={{
            span: 8,
          }}
          wrapperCol={{
            span: 16,
          }}
          initialValues={{
            remember: true,
          }}
          onFinish={createSpeaker}
          onFinishFailed={() => {
            console.log("faild");
          }}
          autoComplete="off"
        >
          <div
            className="etn-fw-speaker-section"
            style={{ marginBottom: "20px" }}
          >
            <Row gutter={[20, 20]}>
              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("Name", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                  required={true}
                >
                  <Input
                    type={"text"}
                    value={etn_speaker_create ? etn_speaker_create?.name : ""}
                    onChange={(e) => {
                      onChangeSpeakerData("name", e.target.value);
                    }}
                    size="small"
                    placeholder={__("Enter name", "eventin-pro")}
                  />
                </Form.Item>
              </Col>
              <Col xs={24} sm={24} md={12}>
                <Form.Item
                  label={__("Designation", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <Input
                    type={"text"}
                    value={
                      etn_speaker_create ? etn_speaker_create?.designation : ""
                    }
                    onChange={(e) => {
                      onChangeSpeakerData("designation", e.target.value);
                    }}
                    size="small"
                    placeholder={__("Enter designation", "eventin-pro")}
                  />
                </Form.Item>
              </Col>
              <Col xs={24} sm={24} md={24}>
                <Form.Item
                  initialValue={
                    etn_speaker_create ? etn_speaker_create?.email : ""
                  }
                  label={__("Email", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                  name="email"
                  rules={[
                    {
                      pattern: /\S+@\S+\.\S+/,
                      message: __("Please enter a valid E-mail", "eventin-pro"),
                    },
                  ]}
                >
                  <Input
                    type="email"
                    onChange={(e) => {
                      onChangeSpeakerData("email", e.target.value);
                    }}
                    size="small"
                    placeholder={__("Enter email", "eventin-pro")}
                  />
                </Form.Item>
              </Col>

              <Col xs={24} sm={24} md={12} lg={8}>
                <Row>
                  <Col span={24}>
                    <p className="etn-mltv-form-item-label">
                      {__("Speaker profile image:", "eventin-pro")}
                    </p>
                  </Col>
                </Row>
                <Row gutter={[10, 0]}>
                  <Col span={12}>
                    <UploadButton
                      onClick={() => {
                        handleWpUploader({
                          name: "thumbnail_id",
                          value: "image",
                        });
                      }}
                      name={"speaker_profile"}
                      url={etn_speaker_create?.image}
                    />
                  </Col>
                  <Col span={12}>
                    <ImgPreview
                      name="speaker_profile_url"
                      url={etn_speaker_create?.image}
                      cb={() => {
                        onChangeSpeakerProfileData("");
                      }}
                    />
                  </Col>
                </Row>
              </Col>
              <Col xs={24} sm={24} md={12} lg={8}>
                <Row>
                  <Col span={24}>
                    <p className="etn-mltv-form-item-label">
                      {__("Company logo:", "eventin-pro")}
                    </p>
                  </Col>
                </Row>
                <Row gutter={[10, 0]}>
                  <Col span={12}>
                    <UploadButton
                      onClick={() => {
                        handleWpUploader({
                          name: "company_logo",
                          value: "company_logo_url",
                        });
                      }}
                      name={"company_logo"}
                      url={etn_speaker_create?.company_logo_url}
                    />
                  </Col>
                  <Col span={12}>
                    <ImgPreview
                      name="company_logo_url"
                      url={etn_speaker_create?.company_logo_url}
                      cb={() => {
                        onChangeSpeakerLogoData("");
                      }}
                    />
                  </Col>
                </Row>
              </Col>

              <Col xs={24} sm={24} md={24}>
                <Form.Item
                  label={__("Summary", "eventin-pro")}
                  labelCol={24}
                  wrapperCol={24}
                >
                  <TextArea
                    value={
                      etn_speaker_create ? etn_speaker_create?.summary : ""
                    }
                    rows={4}
                    placeholder="Speaker summary"
                    onChange={(e) => {
                      onChangeSpeakerData("summary", e.target.value);
                    }}
                  />
                </Form.Item>
              </Col>
            </Row>
          </div>
          <div className="etn-fw-speaker-section">
            <Row>
              <SocialRepeater
                socials={etn_speaker_create?.socials}
                setIconModal={setIconModal}
                removeSocial={removeSocial}
                setSocialData={setSocialData}
                iconModal={iconModal}
              />

              <Col xs={24} sm={24} md={24}>
                <Button
                  onClick={() => {
                    addMoreSocial(etn_speaker_create);
                  }}
                >
                  {__("Add More", "eventin-pro")}
                </Button>
              </Col>
            </Row>
          </div>
          <div className="etn-fw-speaker-section" style={{ margin: "20px 0" }}>
            <Row>
              <Col xs={24} sm={24} md={24}>
                <SelectWithCustomBtn
                  name={"category"}
                  values={etn_speaker_create?.category}
                  data={organizerData}
                  getData={getData}
                  label={"Category"}
                  placeholder={"Select category"}
                  valueField={"term_id"}
                  labelField={"name"}
                  create={true}
                  onClick={addSpeakerCat}
                />
              </Col>
            </Row>
          </div>
          <Row>
            <Col span={24} style={{textAlign: 'right'}}>
              {/* <Form.Item> */}
                <Button type="primary" htmlType="submit">
                  {!id
                    ? __("Create Speaker", "eventin-pro")
                    : __("Update Speaker", "eventin-pro")}
                </Button>
              {/* </Form.Item> */}
            </Col>
          </Row>
        </Form>
      </div>

      {/* <Row>
        <Col span={6} offset={18}>
          {!id && <Button onClick={createSpeaker}>Create Speaker</Button>}
          {id && <Button onClick={createSpeaker}>Update Speaker</Button>}
        </Col>
      </Row> */}
    </div>
  );
}

export default CreateSpeaker;
