import { Col, Form, Input, Row, Switch } from "antd";
import React, { useContext } from "react";
import EventContext from "../../context/EventContext";
import dayjs from "dayjs";
import RangePicker from "./RangePicker";
import TimePicker from "./TimeRangePicker";
const { __ } = wp.i18n;

function EventInfoBasic() {
  const { state, onChangeFormData, setTimeZoneData } = useContext(EventContext);

  const {
    etn_is_virtual,
    etn_event_location,
    joining_link,
    event_timezone,
    etn_end_date,
    etn_start_date,
    timezone,
    etn_end_time,
    etn_start_time,
  } = state;

  const onChangeVirtual = (is_virtual) => {
    onChangeFormData("etn_is_virtual", is_virtual);
  };

  // configuration for disable time(second)
  const disabledTime = (_, type) => {
    const range = (start, end) => {
      const result = [];

      for (let i = start; i < end; i++) {
        result.push(i);
      }

      return result;
    };
    if (type === "start") {
      return {
        disabledHours: () => range(0, 0).splice(4, 20),
        disabledMinutes: () => range(0, 0),
        disabledSeconds: () => [0, 10],
      };
    }

    return {
      disabledHours: () => range(0, 0).splice(4, 20),
      disabledMinutes: () => range(0, 0),
      disabledSeconds: () => [0, 59],
    };
  };

  return (
    <>
      {/* <Row gutter={[12, 12]}>
        <Col xs={24} sm={24} md={24}>
          <Row>
            <Col span={24}>
              <Form.Item
                // label={__("Virtual event", 'eventin-pro')}
                // labelCol={24}
                wrapperCol={24}
              >
                <div class="etn-mltv-meta">
                  <p className="etn-mltv-lable-headding">
                    {__("Virtual event", "eventin-pro")}
                  </p>
                  <Switch onChange={onChangeVirtual} checked={etn_is_virtual} />
                </div>
              </Form.Item>
            </Col>
          </Row>
        </Col>
      </Row> */}

      <Row gutter={[12, 12]}>
        {/* {etn_is_virtual ? (
          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Joining Link", "eventin-pro")}
              labelCol={24}
              wrapperCol={24}
            >
              <Input
                type={"text"}
                value={joining_link ? joining_link : ""}
                onChange={(e) => [
                  onChangeFormData("joining_link", e.target.value),
                ]}
                size="small"
                placeholder={__("Enter link", "eventin-pro")}
              />
            </Form.Item>
          </Col>
        ) : ( */}
          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Venue", "eventin-pro")}
              labelCol={24}
              wrapperCol={24}
            >
              <Input
                type={"text"}
                value={etn_event_location ? etn_event_location : ""}
                onChange={(e) => [
                  onChangeFormData("etn_event_location", e.target.value),
                ]}
                size="small"
                placeholder={__("Event location", "eventin-pro")}
              />
            </Form.Item>
          </Col>
        {/* )} */}
        <Col xs={24} sm={24} md={12}>
          <Form.Item
            label={__("Timezone", "eventin-pro")}
            labelCol={24}
            wrapperCol={24}
            className="etn-mltv-timezone-select"
          >
            <select
              dangerouslySetInnerHTML={{ __html: timezone }}
              onChange={(e) => {
                onChangeFormData("event_timezone", e.target.value);
              }}
              value={event_timezone}
            ></select>
          </Form.Item>
        </Col>
      </Row>

      <Row gutter={[12, 12]}>
        <Col xs={24} sm={24} md={12}>
          <Row>
            <Col span={24}>
              <Form.Item
                label={__("Start and end date", "eventin-pro")}
                labelCol={24}
                wrapperCol={24}
              >
                <RangePicker
                  value={
                    etn_start_date && etn_end_date
                      ? [dayjs(etn_start_date), dayjs(etn_end_date)]
                      : []
                  }
                  onChange={(er) => {
                    onChangeFormData(
                      "etn_start_date",
                      dayjs(er[0].$d).format("YYYY-MM-DD")
                    );
                    onChangeFormData(
                      "etn_end_date",
                      dayjs(er[1].$d).format("YYYY-MM-DD")
                    );
                  }}
                />
              </Form.Item>
            </Col>
          </Row>
        </Col>
        <Col xs={24} sm={24} md={12}>
          <Row>
            <Col span={24}>
              <Form.Item
                label={__("Start and end time", "eventin-pro")}
                labelCol={24}
                wrapperCol={24}
              >
                <TimePicker
                  disabledTime={disabledTime}
                  value={
                    etn_start_time && etn_end_time
                      ? [
                          dayjs(etn_start_time, "h:mm A"),
                          dayjs(etn_end_time, "h:mm A"),
                        ]
                      : []
                  }
                  onChange={(er) => {
                    onChangeFormData(
                      "etn_start_time",
                      dayjs(er[0].$d).format("h:mm A")
                    );
                    onChangeFormData(
                      "etn_end_time",
                      dayjs(er[1].$d).format("h:mm A")
                    );
                  }}
                />
              </Form.Item>
            </Col>
          </Row>
        </Col>
      </Row>
    </>
  );
}

export default EventInfoBasic;
