import React, { useState, useContext } from "react";
import { DeleteOutlined } from "@ant-design/icons";
import EventContext from "../../context/EventContext";
const { __ } = wp.i18n;

function ImgPreview({ url, name, cb}) {
  const { state, onChangeFormData } = useContext(EventContext);
  const [showIcon, setShowIcon] = useState(false);

  /**
   * Handler for show delete icon on image preview section
   */
  const mouseEnter = () => {
    setShowIcon(true);
  };

  /**
   * Handler for hide delete icon on image preview section.
   */
  const mouseLeave = () => {
    setShowIcon(false);
  };

  /**
   * Handler for remove image data from context api
   */
  const removeImage = () => {
    onChangeFormData(name, "");
    onChangeFormData(`${name}_id`, "");
    if(cb){
      cb()
    }
  };
  return (
    <div
      className="etn-mltv-img-prev-wrap"
      onMouseEnter={mouseEnter}
      onMouseLeave={mouseLeave}
    >
      {url ? (
        <>
          <img className="etn-mltv-img-prev" src={url} />
          {showIcon && (
            <span className="etn-mltv-img-prev-bin" onClick={removeImage}>
              <DeleteOutlined className="etn-mltv-img-prev-bin-svg" />
            </span>
           )}
        </>
      ) : (
        <div className="etn-mltv-img-prev etn-mltv-img-prev-div">
          <span className="etn-mltv-img-prev-text">
          {__("Preview will appear here", 'eventin-pro')}
          </span>
        </div>
      )}
    </div>
  );
}

export default ImgPreview;
