import { Checkbox, Col, Form, InputNumber, Select } from "antd";
import React, { useContext, useState } from "react";
import EventContext from "../../context/EventContext";
const CheckboxGroup = Checkbox.Group;
const { Option } = Select;
const { __ } = wp.i18n;


function RepeatOn({ repeat, data }) {
  const { state, onChangeFormData } = useContext(EventContext);
  const {
    recurrence_daily_interval,
    recurrence_weekly_day,
    recurrence_weekly_days,
    recurrence_yearly_date,
    recurrence_monthly_date,
    recurrence_yearly_month
  } = state;

  const plainOptions = [
    { weekDay: 0, day: "Sun" },
    { weekDay: 1, day: "Mon" },
    { weekDay: 2, day: "Tue" },
    { weekDay: 3, day: "Wed" },
    { weekDay: 4, day: "Thu" },
    { weekDay: 5, day: "Fri" },
    { weekDay: 6, day: "Sat" },
  ];

  const defaultCheckedList = [];

  const [checkedList, setCheckedList] = useState(recurrence_weekly_days ? recurrence_weekly_days : defaultCheckedList);

  /**
   * Handler for onChange event repeate on options.
   * @param {Array} list Array of weekly days
   */
  const onChange = (list) => {
    const _weekDay = [...plainOptions].filter((item) => {
      return [...list].includes(item.day)
    });
    const weekday = [..._weekDay].map(item => item.weekDay)
    setCheckedList(list);
    onChangeFormData("recurrence_weekly_days", list);
    onChangeFormData("recurrence_weekly_day", weekday);
  };

  /**
   * Handler for yearly month value change
   * @param {any} val yearly month number/name
   */
  const handleMonthChange = (val) => {
    onChangeFormData("recurrence_yearly_month", val);
  }

  if (!repeat) {
    return null;
  }
  return (
    <>
      <Col span={12}>{__(data?.dependencyLabel, 'eventin-pro')} </Col>
      <Col span={12}>
        <Form.Item name="recurrence_daily_interval">
          {repeat == "daily" && (
            <InputNumber
              value={
                recurrence_daily_interval ? recurrence_daily_interval : null
              }
              onChange={(val) => {
                onChangeFormData("recurrence_daily_interval", val);
              }}
            />
          )}
          {repeat == "weekly" && (
            <CheckboxGroup
              options={plainOptions?.map((item) => item.day)}
              value={checkedList}
              onChange={onChange}
            />
          )}
          {repeat == "monthly" && (
            <InputNumber
              value={recurrence_monthly_date ? recurrence_monthly_date : null}
              onChange={(val) => {
                onChangeFormData("recurrence_monthly_date", val);
              }}
            />
          )}
          {repeat == "yearly" && (
            <Select
              placeholder={__("Select month", 'eventin-pro')}
              size="large"
              onChange={handleMonthChange}
              value={recurrence_yearly_month ? recurrence_yearly_month : null}
            >
              {months.map(({ sl, name }, i) => {
                return (
                  <Option key={`m-${sl}`} value={sl}>
                    {__(name, 'eventin-pro')}
                  </Option>
                );
              })}
            </Select>
          )}
        </Form.Item>
      </Col>
      <Col span={12}>{__("Yearly Month's Day", 'eventin-pro')}</Col>
      <Col>
        {repeat == "yearly" && (
          <Form.Item>
            <InputNumber
              value={recurrence_yearly_date ? recurrence_yearly_date : null}
              onChange={(val) => {
                onChangeFormData("recurrence_yearly_date", val);
              }}
            />
          </Form.Item>
        )}
      </Col>
    </>
  );
}

export default RepeatOn;

export const months = [
  { sl: 1, name: "January" },
  { sl: 2, name: "February" },
  { sl: 3, name: "March" },
  { sl: 4, name: "April" },
  { sl: 5, name: "May" },
  { sl: 6, name: "June" },
  { sl: 7, name: "July" },
  { sl: 8, name: "August" },
  { sl: 9, name: "September" },
  { sl: 10, name: "October" },
  { sl: 11, name: "November" },
  { sl: 12, name: "December" },

];
