import { Select, Spin } from "antd";
import React, { useRef, useState } from "react";
const { Option } = Select;
const { __ } = wp.i18n;

function DebounceSelect({
  onClickSearch,
  data,
  valueField,
  labelField,
  debounceTimeout = 800,
  ...props
}) {
  const [fetching, setFetching] = useState(false);
  const [options, setOptions] = useState(data || []);
  const fetchRef = useRef(0);

  /**
   * Handler for filter specific option for a search key
   * @param {String} search Search key dropdown
   */
  const debounceFetcher = (search) => {
    fetchRef.current += 1;
    const fetchId = fetchRef.current;
    setFetching(true);
    const _data = [...data].filter((item) => {
      return item.name.toString().toLowerCase().includes(search.toLowerCase());
    });
    setOptions(_data);
    setFetching(false);
  };

  return (
    <Select
      labelInValue
      filterOption={false}
      onSearch={debounceFetcher}
      onClick={() => {
        setOptions(data);
      }}
      notFoundContent={fetching ? <Spin size="small" /> : __('Not data found.', 'eventin-pro')}
      {...props}
      // options={options}
    >
      {options?.map((op, i) => {
        return <Option key={`${op[valueField]}-${i}`} value={op[valueField]}>{op[labelField]}</Option>;
      })}
    </Select>
  );
} // Usage of DebounceSelect

const SearchAndSelect = ({
  placeholder,
  data,
  getData,
  setData,
  name,
  values,
  valueField,
  labelField,
}) => {
  const [value, setValue] = useState(values ? values : []);
  return (
    <DebounceSelect
      mode="multiple"
      value={value}
      valueField={valueField}
      labelField={labelField}
      data={data}
      placeholder={placeholder ? __(placeholder, 'eventin-pro') : __("Search and select", 'eventin-pro')}
      onChange={(newValue) => {
        setValue(newValue);
        getData(newValue, setData, name);
      }}
      onClickSearch={() => {
        setValue(value ? value : "");
      }}
      style={{
        width: "100%",
      }}
    />
  );
};

export default SearchAndSelect;
