import React, { useContext, useState } from "react";
import {
  Button,
  Col,
  Form,
  Input,
  notification,
  Row,
  Select,
  Space,
} from "antd";
import { PlusOutlined } from "@ant-design/icons";

import PlusSvg from "./PlusSvg";
import EventContext from "../../context/EventContext";
import CreateSchedule from "./CreateSchedule";
import CreateSpeaker from "./CreateSpeaker";
import CreateOrganizer from "./CreateOrganizer";
import { openNotification } from "../../helpers/helper";
const { Option } = Select;
const { __ } = wp.i18n;

function SelectWithCustomBtn({
  name,
  values,
  data,
  getData,
  label,
  placeholder,
  valueField,
  labelField,
  create,
  onClick,
}) {
  const { state, onChangeFormData, onCreateSpeakerCat } = useContext(EventContext);
  const {
    etn_event_schedule_create,
    etn_event_speaker_create,
    etn_event_organizer_create,
    setOpen,
    speaker_category_name,
  } = state;
  const addItem = (e, name) => {};

  /**
   * Handler for CREATE speaker category
   * @returns Nothing
   */
  const createSpeakerCategory = () => {
    // cannot submit when category name is empty.
    if (!speaker_category_name || speaker_category_name?.trim() == "") {
      return openNotification(
        notification,
        "error",
        __("Input missing!", "eventin-pro"),
        __("Category name should not empty!", "eventin-pro")
      );
    }
    
    // React context provider method to create speaker category.
    onCreateSpeakerCat(speaker_category_name)

  };

  return (
    <Col xs={24} sm={24} md={24}>
      <Form.Item label={__(label, "eventin-pro")} labelCol={24} wrapperCol={24}>
        <Select
          open={setOpen}
          mode={"multiple"}
          showSearch
          showArrow
          placeholder={__(placeholder, "eventin-pro")}
          optionFilterProp="children"
          defaultValue={values ? values?.map(item => item[valueField]) : []}
          onDropdownVisibleChange={(visible) => {
            onChangeFormData("setOpen", visible);
          }}
          onChange={(value, option) => {
            // const _value = [...data].filter((item) => {return item[valueField] == value})
            getData(value, valueField, name);
            // setOpen(false);
            onChangeFormData(`${name}_create`, false);
          }}
          filterOption={(input, option) => {
            return option.children.toLowerCase().includes(input.toLowerCase());
          }}
          dropdownRender={(menu) => {
            return (
              <>
                {menu}
                {create && (
                  <Button
                 
                  type="text"
                  className="etn-btn-speaker-create-new"
                  onClick={(e) => onClick(e, name)}
                >
                   {__("Create New", "eventin-pro")} {label} <PlusSvg />
                </Button>
                )}
              </>
            );
          }}
        >
          {data?.map((item, i) => {
            return (
              <Option
                key={`op-${item[valueField]}-${i}`}
                value={item[valueField]}
              
              >
                {item[labelField]}
              </Option>
            );
          })}
        </Select>
      </Form.Item>

      {name == "etn_event_schedule" && state[`${name}_create`] && (
        <CreateSchedule />
      )}
      {name == "category" && state[`${name}_create`] && (
        <Row gutter={[20, 0]} align="middle" justify="center" style={{marginTop: '20px'}}>
          <Col xs={24} sm={24} md={12}>
            <Input
              type="text"
              placeholder="Enter speaker category"
              onChange={(e) => {
                onChangeFormData("speaker_category_name", e.target.value);
              }}
            />
          </Col>
          <Col xs={24} sm={24} md={12}>
            <Button onClick={createSpeakerCategory}> {__("Create", "eventin-pro")}</Button>
          </Col>
        </Row>
      )}
      {name == "etn_event_organizer" && state[`${name}_create`] && (
        <CreateOrganizer />
      )}
      {name == "etn_event_speaker" && state[`${name}_create`] && (
        <CreateSpeaker />
      )}
    </Col>
  );
}

export default SelectWithCustomBtn;
