import {
  Button, Col, Collapse, Form, Input,
  InputNumber,
  Row,
  Select,
  Switch
} from "antd";
import React, { useContext, useState } from "react";
import EventContext from "../../context/EventContext";
import EventInfoBasic from "../common/EventInfoBasic";
import SearchAndSelect from "../common/SearchAndSelect";
import SelectWithCustomBtn from "../common/SelectWithCustomBtn";
const { __ } = wp.i18n;


const { Option } = Select;
const { Panel } = Collapse;

function EventInfo() {
  const { state, onChangeFormData, setTimeZoneData } = useContext(EventContext);
  const {
    etn_start_date,
    etn_end_date,
    etn_start_time,
    etn_end_time,
    etn_event_location,
    //etn_event_speaker,
    etn_event_schedule,
    recurring_enabled,
    recurrence_freq,
    recurrence_span,
    recurrence_ends_on,
    timezone,
    event_timezone,
    etn_ticket_availability,
    etn_ticket_variations,
    scheduleData, organizerData, etn_event_organizer, etn_event_speaker
  } = state;
  const {  } = state;
  const [placement, SetPlacement] = useState("topLeft");
  const [startDate, setStartDate] = useState("");
  const [endDate, setEndDate] = useState("");
  const [startTime, setStartTime] = useState("");
  const [endTime, setEndTime] = useState("");

  const [variations, setVariations] = useState([
    {
      etn_ticket_name: "",
      etn_ticket_price: "",
      etn_avaiilable_tickets: "",
      etn_min_ticket: "",
      etn_max_ticket: "",
    },
  ]);

  const variation = {
    etn_ticket_name: "",
    etn_ticket_price: "",
    etn_avaiilable_tickets: "",
    etn_min_ticket: "",
    etn_max_ticket: "",
  };

  const onChange = (limited) => {
    onChangeFormData("etn_ticket_availability", limited);
  };

  /**
   * Handler for setting ticket variation data.
   * @param {String} value 
   * @param {String} name 
   * @param {Number} i index of ticket variation repeater
   */
  const ticketVariationChange = (value, name, i) => {
    let _variations = JSON.parse(JSON.stringify(etn_ticket_variations));
    let _variation = _variations[i];
    _variation[name] = value;
    _variations[i] = _variation;
    onChangeFormData("etn_ticket_variations", _variations);
  };


  /**
   * Handler for rending ticket variation repeater
   * @returns JSX
   */
  const renderTicketVariations = () => {
    return etn_ticket_variations?.map((link, i) => {
      return (
        <div className="etn-mltv-single-panel" key={`etn_ticket_variations-${i}`}>
          <Row>
            <Col span={23}>
              <Collapse
                defaultActiveKey={["1"]}
                expandIconPosition={"end"}
              >
                <Panel header={__(`Ticket variation ${i + 1}`, 'eventin-pro')} key="1">
                  <div className="etn-mltv-ticket-wrapper">
                    <p className="etn-mltv-ticket-title">{__("Ticket Name:", 'eventin-pro')}</p>
                    <div className="tc-content">
                     
                        <Input
                          placeholder={__("Ticket Name", 'eventin-pro')}
                          value={link["etn_ticket_name"]}
                          onChange={(e) => {
                            ticketVariationChange(
                              e.target.value,
                              `etn_ticket_name`,
                              i
                            );
                          }}
                        />
                    </div>
                    <p className="etn-mltv-ticket-title">{__("Ticket Price:", 'eventin-pro')}</p>
                    <div className="tc-content">
                      <InputNumber
                      
                        value={link["etn_ticket_price"]}
                        onChange={(value) => {
                          ticketVariationChange(value, `etn_ticket_price`, i);
                        }}
                      />
                    </div>
                    {etn_ticket_availability && etn_ticket_availability != 'no' && <>
                      <p className="etn-mltv-ticket-title">{__("No. of Tickets:", 'eventin-pro')}</p>
                      <div className="tc-content">
                        <InputNumber
                          value={link["etn_avaiilable_tickets"]}
                          onChange={(value) => {
                            ticketVariationChange(
                              value,
                              `etn_avaiilable_tickets`,
                              i
                              );
                            }}
                            />
                      </div>
                    </>}
                    <p className="etn-mltv-ticket-title">
                    {__("Minimum Purchase Qty:", 'eventin-pro')}
                    </p>
                    <div className="tc-content">
                      <InputNumber
                        value={link["etn_min_ticket"]}
                        onChange={(value) => {
                          ticketVariationChange(value, `etn_min_ticket`, i);
                        }}
                      />
                    </div>
                    <p className="etn-mltv-ticket-title">
                    {__("Maximum Purchase Qty:", 'eventin-pro')}
                    </p>
                    <div className="tc-content">
                      <InputNumber
                        value={link["etn_max_ticket"]}
                        onChange={(value) => {
                          ticketVariationChange(value, `etn_max_ticket`, i);
                        }}
                      />
                    </div>
                  </div>
                </Panel>
              </Collapse>
            </Col>
            {i > 0 ? (
              <Col span={1}>
                <Button
                  className="etn-close-button"
                  type="danger"
                  size={"small"}
                  onClick={() => {
                    onChangeFormData(
                      "etn_ticket_variations",
                      etn_ticket_variations.filter((item, index) => i !== index)
                    );
                  }}
                >
                  X
                </Button>
              </Col>
            ) : (
              <Col span={1}></Col>
            )}
          </Row>
        </div>
      );
    });
  };
 

  /**
   * Handler for setting organizer and schedule data
   * @param {String} value 
   * @param {CallableFunction} setData 
   * @param {String} name 
   */
  const getData = (value, propName, name) => {
    const ids = [...value].map((item) => {
      return item[propName];
    });
    onChangeFormData(`${name}_ids`, ids);
    onChangeFormData(name, value);
  };


  return (
    <div className="etn-mltv-event-info">
      <h1 className="etn-mltv-step-info-title">{__("Event Info", 'eventin-pro')}</h1>
      <div className="etn-mltv-event-basic-info etn-mltv-general-block">
        <EventInfoBasic />
        {/* <Row gutter={[12, 12]}>
          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Organizer", 'eventin-pro')}
              labelCol={24}
              wrapperCol={24}
            >
              <Select
                className={'etn-frontend-speaker-select'}
                showSearch
                placeholder={__("Select organizer", 'eventin-pro')}
                optionFilterProp="children"
                value={etn_event_organizer}
                onChange={(value) => {
                  getData(value, null, "etn_event_organizer");
                }}
                filterOption={(input, option) =>
                  option.children.toLowerCase().includes(input.toLowerCase())
                }
                
              >
                {organizerData?.map((item) => {
                  return <Option value={item.slug}>{item.name}</Option>;
                })}
              
              </Select>
            </Form.Item>
          </Col>
          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Schedule", 'eventin-pro')}
              labelCol={24}
              wrapperCol={24}
            >
              <SearchAndSelect
                data={scheduleData}
                placeholder={__("Search schedule", 'eventin-pro')}
                getData={getData}
                setData={'value'}
                name={"etn_event_schedule"}
                values={etn_event_schedule}
                valueField={"ID"}
                labelField={"post_title"}
                
              />
            </Form.Item>
          </Col>
        </Row> */}
      </div>

       {/* schedule/speaker/organizer block */}
       <div className="etn-mltv-event-basic-info etn-mltv-general-block">
      <Row gutter={[12, 12]}>

      <Col xs={24} sm={24} md={24}>
            <Form.Item
              label={__("Schedule", 'eventin-pro')}
              labelCol={24}
              wrapperCol={24}
            >
              <SearchAndSelect
                data={scheduleData}
                placeholder={__("Search schedule", 'eventin-pro')}
                getData={getData}
                setData={'value'}
                name={"etn_event_schedule"}
                values={etn_event_schedule}
                valueField={"ID"}
                labelField={"post_title"}
                
              />
            </Form.Item>
          </Col>
        {/* <SelectWithCustomBtn
          name = {'etn_event_schedule'}
          values = {[]} data={etn_event_schedule} getData ={getData}
          label={"Schedule"} placeholder={"Select schedule"} valueField={"term_id"} labelField={"name"}
        /> */}
        <SelectWithCustomBtn
          name = {'etn_event_speaker'}
          values = {etn_event_speaker} data={organizerData} getData ={getData} create={false}
          label={"Speaker"} placeholder={"Select speaker"} valueField={"term_id"} labelField={"name"}
        />
        {/* <SelectWithCustomBtn
          name = {'etn_event_organizer'}
          values = {etn_event_organizer} data={organizerData} getData ={getData}
          label={"Organizer"} placeholder={"Select organizer"} valueField={"term_id"} labelField={"name"}
        /> */}
          
        </Row>
      </div>

      {/* Ticket details goes here... */}

      <div className="etn-mltv-event-info">
        <h1 className="etn-mltv-step-info-title">{__("Ticket Details", 'eventin-pro')}</h1>
        <div
          className="etn-mltv-event-ticket-info etn-mltv-general-block"
          gutter={[12, 12]}
        >
          <div className="etn-mltv-meta">
            <p className="etn-mltv-lable-headding">{__("Limited tickets", 'eventin-pro')}</p>
            <Switch onChange={onChange} checked={etn_ticket_availability && etn_ticket_availability != 'no'} />
          </div>

         
            <Col span={24}>
              <p className="etn-mltv-subheadding">{__("Ticket variation", 'eventin-pro')}</p>
            </Col>
        

          
            <Col span={24}>{renderTicketVariations()}</Col>
          
          
            <Button
              className="etn-btn-primary etn-mltv-variation-add"
              size={"medium"}
              onClick={() => {
                onChangeFormData("etn_ticket_variations", [
                  ...etn_ticket_variations,
                  variation,
                ]);
              }}
            >
              {__("Add", 'eventin-pro')}
            </Button>
          
        </div>
      </div>
    </div>
  );
}

export default EventInfo;

export const repeatOnData = [
  { label: "Daily", value: "daily", dependencyLabel: "Recurrence Interval" },
  { label: "Weekly", value: "weekly", dependencyLabel: "On" },
  { label: "Monthly", value: "monthly", dependencyLabel: "On the date of " },
  { label: "Yearly", value: "yearly", dependencyLabel: "In the month of " },
];
