import { Button, Col, Form, Input, Row } from "antd";
import React, { useContext, useState } from "react";
import ReactQuill from "react-quill";
import "react-quill/dist/quill.snow.css";
import EventContext from "../../context/EventContext";
import IconModal from "../common/IconModal";
import ImgPreview from "../common/ImgPreview";
import SearchAndSelect from "../common/SearchAndSelect";
import UploadButton from "../common/UploadButton";
import { etn_speaker_socials } from "../../stores/store";
import SocialRepeater from "../common/SocaialRepeater";
const { __ } = wp.i18n;

function GeneralInfo() {
  const { state, onChangeFormData, setSocialLinks } = useContext(EventContext);
  const {
    step,
    categoryData,
    subCategoryData,
    tags,
    etn_event_socials,
    etn_category,
    etn_tags,
    etn_event_logo,
    etn_banner_bg_image,
    etn_feature_image,
    etn_social_title,
    etn_social_url,
    post_title_error,
  } = state;
  const [category, setCategory] = useState([]);
  const [tag, setTag] = useState([]);

  const [iconModal, setModal] = useState(false);
  const [socialLinkIndex, setSocialLinkIndex] = useState(null);

/**
 * Handler for show/hide Icon madal for social icons
 * @param {Boolean} modalStatue True/False State of the Icon modal
 * @param {Number} socialLinkIndex index of social link
 */
  const setIconModal = (modalStatue, socialLinkIndex = null) => {
    setModal(modalStatue);
    setSocialLinkIndex(socialLinkIndex);
  };

  const links = {
    icon: "",
    etn_social_title: "",
    etn_social_url: "",
  };

  /**
   * Handler for category and tag select
   * @param {Array} value  
   * @param {CallableFunction} setData 
   * @param {String} name 
   */
  const getData = (value, setData, name) => {
    const ids = [...value].map((item) => {
      return item.value;
    });
    setData(ids);
    onChangeFormData(name == "category" ? "etn_category" : "etn_tags", value);
    onChangeFormData(
      name == "category" ? "etn_category_ids" : "etn_tags_ids",
      ids
    );
  };

  /**
   * Handler for social icon list on icon modal
   * @param {String} value 
   * @param {String} name 
   */
  const getIcon = (value, name) => {
    let _socialLinks = JSON.parse(JSON.stringify(etn_event_socials));
    let _socialLink = _socialLinks[socialLinkIndex];
    _socialLink[name] = value;
    _socialLinks[socialLinkIndex] = _socialLink;
    setSocialLinks(_socialLinks);
    onChangeFormData("etn_event_socials", _socialLinks);
  };

  /**
   * Handler for format and set social icon data
   * @param {String} value 
   * @param {String} name 
   */
  const setSocialData = (value, name, i) => {
    let _socialLinks = JSON.parse(JSON.stringify(etn_event_socials));
    let _socialLink = _socialLinks[i];
    _socialLink[name] = value;
    _socialLinks[i] = _socialLink;
    setSocialLinks(_socialLinks);
    onChangeFormData("etn_event_socials", _socialLinks);
  };


  // config obj for ReactQuill rich text editor
  const modules = {
    toolbar: [
      [{ header: [1, 2, false] }],
      ["bold", "italic", "underline", "strike", "blockquote"],
      [
        { list: "ordered" },
        { list: "bullet" },
        { indent: "-1" },
        { indent: "+1" },
      ],
      ["link", "image"],
      ["clean"],
    ],
  };

  // config obj for ReactQuill rich text editor
  const formats = [
    "header",
    "bold",
    "italic",
    "underline",
    "strike",
    "blockquote",
    "list",
    "bullet",
    "indent",
    "link",
    "image",
  ];


  /**
   * Handler for image uploading
   * @param {String} name 
   */
  const handleWpUploader = (name) => {
    const custom_uploader = wp
      .media({
        title: "Insert image",
        library: {
          type: "image",
        },
        button: {
          text: "Use this image", // button label text
        },
        // multiple,
      })
      .on("select", function (sele) {
        const attachment = custom_uploader
          .state()
          .get("selection")
          .first()
          .toJSON();
        onChangeFormData(name, attachment.url);
        onChangeFormData(`${name}_id`, attachment.id);
      })
      .open();
  };


  /**
   * Handler for REMOVE social item from social repeater
   * @param {Number} linkIndex 
   */
  const removeSocial = (linkIndex) => {
    let _socialLinks = JSON.parse(JSON.stringify(etn_event_socials));

    if ([..._socialLinks].length == 1) {
      _socialLinks = [etn_speaker_socials];
    } else {
      _socialLinks = [..._socialLinks].filter(
        (sLink, index) => linkIndex != index
      );
    }

    onChangeFormData("etn_speaker_socials", _socialLinks);
  };


  return (
    <div className="etn-mltv-general-info">
      <IconModal
        isModalVisible={iconModal}
        setIsModalVisible={setIconModal}
        getIcon={getIcon}
        fieldName={"icon"}
      />
      <h1 className="etn-mltv-step-info-title">{__("General Info", 'eventin-pro')}</h1>
      <Row
        className="etn-mltv-general-basic-info etn-mltv-general-block"
        gutter={[0, 40]}
      >
        <Col span={24}>
          <Form.Item
            label={__("Event title", 'eventin-pro')}
            labelCol={24}
            wrapperCol={24}
            required={true}
          >
            <Input
              type={"text"}
              value={state?.post_title ? state?.post_title : ""}
              onChange={(e) => {
                onChangeFormData("post_title", e.target.value);
                onChangeFormData("post_title_error", "");
              }}
              placeholder={__("Name your event", 'eventin-pro')}
            />
          </Form.Item>
        </Col>
        <Col span={24}>
          <Form.Item
            label={__("Event content", 'eventin-pro')}
            labelCol={24}
            wrapperCol={24}
            required={true}
          >
            <ReactQuill
              theme="snow"
              modules={modules}
              formats={formats}
              value={state.post_content ? state.post_content : ""}
              onChange={(content, delta, source, editor) => {
                if (editor.getText().trim().length) {
                  onChangeFormData("post_content", content);
                  onChangeFormData("post_content_error", "");
                } else {
                  onChangeFormData("post_content", "");
                  onChangeFormData("post_content_error", __("Shouldn't empty!", 'eventin-pro'));
                }
              }}
            />
          </Form.Item>
        </Col>
      </Row>
      <div className="etn-mltv-general-block">
        <Row className="etn-mltv-general-multimedia" gutter={[30, 30]}>
          {/* image start ==================================================== */}
          <Col xs={24} sm={24} md={12} lg={8}>
            <Row>
              <Col span={24}>
                <p className="etn-mltv-form-item-label">{__("Upload event logo:", 'eventin-pro')}</p>
              </Col>
            </Row>
            <Row gutter={[10, 0]}>
              <Col span={12}>
                <UploadButton
                  onClick={handleWpUploader}
                  name={"etn_event_logo"}
                  url={etn_event_logo}
                />
              </Col>
              <Col span={12}>
                <ImgPreview name="etn_event_logo" url={etn_event_logo} />
              </Col>
            </Row>
          </Col>

          <Col xs={24} sm={24} md={12} lg={8}>
            <Row>
              <Col span={24}>
                <p className="etn-mltv-form-item-label">
                  {__("Upload feature image:", 'eventin-pro')}
                </p>
              </Col>
            </Row>
            <Row gutter={[6, 0]}>
              <Col span={12}>
                <UploadButton
                  onClick={handleWpUploader}
                  name={"etn_feature_image"}
                  url={etn_feature_image}
                />
              </Col>
              <Col span={12}>
                <ImgPreview name="etn_feature_image" url={etn_feature_image} />
              </Col>
            </Row>
          </Col>

          <Col xs={24} sm={24} md={12} lg={8}>
            <Row>
              <Col span={24}>
                <p className="etn-mltv-form-item-label">{__("Upload banner image:", 'eventin-pro')}</p>
              </Col>
            </Row>
            <Row gutter={[6, 0]}>
              <Col span={12}>
                <UploadButton
                  onClick={handleWpUploader}
                  name={"etn_banner_bg_image"}
                  url={etn_banner_bg_image}
                />
              </Col>
              <Col span={12}>
                <ImgPreview name="etn_banner_bg_image" url={etn_banner_bg_image} />
              </Col>
            </Row>
          </Col>
        </Row>
        {/* image end ==================================================== */}

        {/* Category start ==================================================== */}
        <Row className="" gutter={[16, 16]}>
          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Add category:", 'eventin-pro')}
              labelCol={24}
              wrapperCol={24}
            >
              <SearchAndSelect
                data={categoryData}
                getData={getData}
                setData={setCategory}
                placeholder={__("Search category", 'eventin-pro')}
                name={"category"}
                values={etn_category}
                valueField={"term_id"}
                labelField={"name"}
              />
            </Form.Item>
          </Col>

          <Col xs={24} sm={24} md={12}>
            <Form.Item
              label={__("Add tags:", 'eventin-pro')}
              name="tags"
              labelCol={24}
              wrapperCol={24}
            >
              <SearchAndSelect
                data={tags}
                getData={getData}
                setData={setTag}
                placeholder={__("Search tags", 'eventin-pro')}
                name={"tag"}
                values={etn_tags}
                valueField={"term_id"}
                labelField={"name"}
              />
            </Form.Item>
          </Col>

          {/* Category end ==================================================== */}
        </Row>
      </div>

      <div className="etn-mltv-general-block">
        <Row>
          <Col span={24}>
            <p className="etn-mltv-form-item-label">{__("Add social links", 'eventin-pro')}</p>
          </Col>
        </Row>
        <SocialRepeater socials={etn_event_socials} setIconModal={setIconModal} removeSocial={removeSocial} setSocialData={setSocialData} iconModal={iconModal} />
        <Row>
          <Button
            className="etn-btn-primary"
            size={"medium"}
            onClick={() => {
              setSocialLinks([...etn_event_socials, links]);
            }}
          >
            {__("Add", 'eventin-pro')}
          </Button>
        </Row>
      </div>
    </div>
  );
}

export default GeneralInfo;

/**
 * List of icons used in icon modal
 */
export const icons = [
  "fab fa-facebook",
  "fab fa-facebook-f",
  "fab fa-facebook-messenger",
  "fab fa-facebook-square",
  "fab fa-linkedin",
  "fab fa-linkedin-in",
  "fab fa-twitter",
  "fab fa-twitter-square",
  "fab fa-uber",
  "fab fa-google",
  "fab fa-google-drive",
  "fab fa-google-play",
  "fab fa-google-wallet",
  "fab fa-linkedin",
  "fab fa-linkedin-in",
  "fab fa-whatsapp",
  "fab fa-whatsapp-square",
  "fab fa-wordpress",
  "fab fa-wordpress-simple",
  "fab fa-youtube",
  "fab fa-youtube-square",
  "fab fa-xbox",
  "fab fa-vk",
  "fab fa-vnv",
  "fab fa-instagram",
  "fab fa-reddit",
  "fab fa-reddit-alien",
  "fab fa-reddit-square",
  "fab fa-pinterest",
  "fab fa-pinterest-p",
  "fab fa-pinterest-square",
  "fab fa-tumblr",
  "fab fa-tumblr-square",
  "fab fa-flickr",
  "fab fa-meetup",
  "fas fa-share",
  "fab fa-vimeo-v",
  "fab fa-weixin",
];
