import {
  Button,
  Col,
  Collapse,
  Form,
  Input,
  InputNumber,
  Row,
  Switch
} from "antd";
import React, { useContext, useState } from "react";
import EventContext from "../../context/EventContext";
const { Panel } = Collapse;
const { __ } = wp.i18n;



function TicketDetails() {
  const { state, onChangeFormData } = useContext(EventContext);
  const { etn_ticket_availability, etn_ticket_variations } = state;
  const [variations, setVariations] = useState([
    {
      etn_ticket_name: "",
      etn_ticket_price: "",
      etn_avaiilable_tickets: "",
      etn_min_ticket: "",
      etn_max_ticket: "",
    },
  ]);

  const variation = {
    etn_ticket_name: "",
    etn_ticket_price: "",
    etn_avaiilable_tickets: "",
    etn_min_ticket: "",
    etn_max_ticket: "",
  };

  /**
   * Handler onChange of event ticket available or not
   * @param {Boolean} limited True/False for checking event ticket available or not
   */
  const onChange = (limited) => {
    onChangeFormData('etn_ticket_availability', limited);
  };

  /**
   * Handler for ticket variantion data change
   * @param {any} value Value of the current field
   * @param {String} name Name of the current field
   * @param {Number} i Index of the current variation(Repeater)
   */
  const ticketVariationChange = (value, name, i) => {
    let _variations = JSON.parse(JSON.stringify(etn_ticket_variations));
    let _variation = _variations[i];
    _variation[name] = value;
    _variations[i] = _variation;
    onChangeFormData('etn_ticket_variations', _variations);
  };

   /**
   * Handler for rending ticket variation repeater
   * @returns JSX
   */
  const renderTicketVariations = () => {
    return etn_ticket_variations?.map((link, i) => {
      return (
        <div className="etn-mltv-single-panel">
          <Row>
            <Col span={22}>
              <Collapse defaultActiveKey={["1"]} onChange={onChange} expandIconPosition={'end'}>
                <Panel header={`Ticket variation ${i + 1}`} key="1">
                  <div className="etn-mltv-ticket-wrapper">
                    <p className="etn-mltv-ticket-title">Ticket Name:</p>
                    <div className="tc-content">
                      <Form.Item>
                        <Input
                          placeholder="Title here"
                          value={link["etn_ticket_name"]}
                          onChange={(e) => {
                            ticketVariationChange(
                              e.target.value,
                              `etn_ticket_name`,
                              i
                            );
                          }}
                        />
                      </Form.Item>
                    </div>

                    <p className="etn-mltv-ticket-title">Ticket Price:</p>
                    <div className="tc-content">
                      <Form.Item>
                        <InputNumber
                          onChange={(value) => {
                            ticketVariationChange(value, `etn_ticket_price`, i);
                          }}
                        />
                      </Form.Item>
                    </div>
                    <p className="etn-mltv-ticket-title">No. of Tickets:</p>
                    <div className="tc-content">
                      <Form.Item>
                        <InputNumber
                          onChange={(value) => {
                            ticketVariationChange(
                              value,
                              `etn_avaiilable_tickets`,
                              i
                            );
                          }}
                        />
                      </Form.Item>
                    </div>
                    <p className="etn-mltv-ticket-title">Minimum Purchase Qty:</p>
                    <div className="tc-content">
                      <Form.Item>
                        <InputNumber
                          onChange={(value) => {
                            ticketVariationChange(value, `etn_min_ticket`, i);
                          }}
                        />
                      </Form.Item>
                    </div>
                    <p className="etn-mltv-ticket-title">Maximum Purchase Qty:</p>
                    <div className="tc-content">
                      <Form.Item>
                        <InputNumber
                          onChange={(value) => {
                            ticketVariationChange(value, `etn_max_ticket`, i);
                          }}
                        />
                      </Form.Item>
                    </div>
                  </div>
                </Panel>
              </Collapse>
            </Col>
            {i > 0 ? (
              <Col span={2}>
                <Button
                  className="etn-close-button"
                  type="danger"
                  size={"small"}
                  onClick={() => {
                    setVariations(
                      variations.filter((item, index) => i !== index)
                    );
                  }}
                >
                  X
                </Button>
              </Col>
            ) : (
              <Col span={2}></Col>
            )}
          </Row>
        </div>
      );
    });
  };

  return (
    <div className="etn-mltv-event-info">
      <h1 className="etn-mltv-step-info-title">Ticket Details</h1>
      <div
        className="etn-mltv-event-ticket-info etn-mltv-general-block"
        gutter={[12, 12]}
      >
        <div className="etn-mltv-meta">
          <p className="etn-mltv-lable-headding">Limited tickets</p>
          <Switch onChange={onChange} checked={etn_ticket_availability && etn_ticket_availability !== 'no'} />
        </div>

        {etn_ticket_availability && <Col span={24}><p className="etn-mltv-subheadding">Ticket variation</p></Col>}

        {etn_ticket_availability && <Col span={24}>{renderTicketVariations()}</Col>}
      </div>
      {etn_ticket_availability && (
        <Button
          className="etn-btn-primary"
          type="primary"
          size={"medium"}
          onClick={() => {
            onChangeFormData('etn_ticket_variations', [...etn_ticket_variations, variation]);
          }}
        >
          Add
        </Button>
      )}
    </div>
  );
}

export default TicketDetails;
