import actions from "../actions/eventAction";
import {
  create_speaker,
  create_speaker_cat,
  delete_event,
  get_attendees_by_event_id,
  get_related_info,
  speakers_api,
  update_attendee_by_id,
  update_ticket_status,
} from "../apiEndpoints/endPoints";
import { getFormData, prepareSpeakerDataForContext } from "./helper";

/**
 * Handler for UPDATE Attendee data (Event Attendee)
 * 
 * @param {Object} Attendee Attendee Object.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const attendeeUpdateHandler = async (
  {
    ID: id,
    etn_info_edit_token,
    etn_name: name,
    etn_email: email,
    etn_phone: phone,
    etn_attendeee_ticket_status: ticket,
    etn_status: payment,
  },
  dispatch,
  state
) => {
  const res = await fetch(update_attendee_by_id, {
    method: "PUT",
    headers: {
      "Content-Type": "application/x-www-form-urlencoded;charset=UTF-8",
    },
    body: new URLSearchParams({
      id,
      etn_info_edit_token,
      name,
      email,
      phone,
      ticket,
      payment,
    }),
  }).catch((err) => {
    console.log("error", err);
  });
  dispatch({
    type: actions.ON_CHANGE_FORM_DATA,
    name: "btn_loader",
    value: false,
  });
  const data = await res.json();
  const { etn_event_attendees, attendeeToUpdate } = { ...state };
  const i = [...etn_event_attendees].findIndex((item) => item?.ID == id);
  if (i != -1) {
    etn_event_attendees[i] = attendeeToUpdate;
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "etn_event_attendees",
      value: etn_event_attendees,
    });
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "show_attendee_edit_modal",
      value: false,
    });
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "attendeeToUpdate",
      value: null,
    });
  }
};

/**
 * Handler for UPDATE Attendee ticket status (Event Attendee)
 * 
 * @param {Object} Object {Attendee Id, Ticket id, Ticket status, Attendee List}.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const ticketStatusHandler = async (
  { attendee, ticket, status, attendeeData },
  dispatch,
  state
) => {
  const url = `${update_ticket_status}`;
  try {
    const res = await fetch(url, {
      method: "PUT",

      body: new URLSearchParams({ attendee, ticket, status }),
    });
    const data = await res.json();

    const { etn_event_attendees } = { ...state };
    const i = [...etn_event_attendees].findIndex(
      (item) => item?.ID == attendee
    );
    if (i != -1) {
      const _attendeeToUpdate = {
        ...attendeeData,
        etn_attendeee_ticket_status: status,
      };
      etn_event_attendees[i] = _attendeeToUpdate;
      dispatch({
        type: actions.ON_CHANGE_FORM_DATA,
        name: "etn_event_attendees",
        value: etn_event_attendees,
      });
      dispatch({
        type: actions.ON_CHANGE_FORM_DATA,
        name: "attendeeToUpdate",
        value: null,
      });
    }
  } catch (error) {
    console.log("err: ", error);
  }
};

/**
 * Handler for FETCH events when page changes
 * 
 * @param {Object} Object {Event id, page no, posts per page}.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const pageChangeHandler = async (
  { event_id, page_no, posts_per_page },
  dispatch,
  state
) => {
  dispatch({
    type: actions.ON_CHANGE_FORM_DATA,
    name: "refresh_loading",
    value: true,
  });
  try {
    const url = `${get_attendees_by_event_id}?event=${event_id}&posts_per_page=${posts_per_page}&paged=${page_no}`;
    const res = await fetch(url);
    const data = await res.json();
    const { content: attendees, count } = data;

    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "refresh_loading",
      value: false,
    });

    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "etn_event_attendees",
      value: attendees,
    });
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "count",
      value: count,
    });
  } catch (error) {
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "refresh_loading",
      value: false,
    });
    console.log("error", err);
  }
};

/**
 * Handler for DELETE event
 * 
 * @param {Object} Object {Event id}.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const eventDeleteHandler = async (
  {
    id
  },
  dispatch,
  state
) => {
  const res = await fetch(`${delete_event}/?ids=${id}`, {
    method: "DELETE",
  }).catch((err) => {
    console.log("error", err);
  });
  dispatch({
    type: actions.ON_CHANGE_FORM_DATA,
    name: "btn_loader",
    value: false,
  });
  const data = await res.json();
  
};


/**
 * Handler for CREATE Speaker
 * 
 * @param {Object} speaker Speaker object to store in the database.
 * @param {Number} id id of speaker if we are tring to update existing speaker.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const createSpeakerHandler = async (
  speaker,id, dispatch, state
) => {
  try {
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: true,
    });

    const user_id = localized_data_obj.author_id;
    let speaker_form_data;
    if(Array.isArray(speaker.category) && Object.keys(speaker.category[0]).length){
      const _cat = speaker?.category?.map(item => item.term_id)
      speaker_form_data = {...speaker, category: _cat.toString(), user_id: user_id}
    }else{
      speaker_form_data = {...speaker, category: speaker.category.toString(), user_id: user_id}
    }
    
    const res = await fetch(`${speakers_api}`, {
      method: id ? "PUT" : "POST",
      body: JSON.stringify(speaker_form_data)
    })

    const data = await res.json();

    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: false,
    });
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "component",
      value: "table",
    });

    const {speakers = []} = state
    const _speaker = prepareSpeakerDataForContext({id, speakers, data})

    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "speakers",
      value:_speaker,
    });
    
  } catch (error) {
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: false,
    });
    console.log("error", error);
  }
 
  
};

/**
 * 
 * @param {Sting} speaker_cat Speaker category name.
 * @param {Function} dispatch Dispatch function of React Context api.
 * @param {Object} state Context api's state object.
 */
export const createSpeakerCatHandler = async (speaker_cat, dispatch, state) => {
  try {
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: true,
    });

    const res = await fetch(`${create_speaker_cat}`, {
      method: "POST",
      body: new URLSearchParams({ name: speaker_cat }),
    })

    const data = await res.json();
   
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: false,
    });
    
  } catch (error) {
    dispatch({
      type: actions.ON_CHANGE_FORM_DATA,
      name: "isLoading",
      value: false,
    });
    console.log("error", error);
  }
 
  
};