import dayjs from "dayjs";
import { etn_speaker_socials, etn_ticket_variations } from "../stores/store";

//buddy boss event data
export const getDataAttrForBuddyBoss = () => {
  const el = document.getElementById('etn_multivendor_form');
  const data = el?.dataset?.etn_buddy_group_id;
  return data
}

/**
 * Handler for prepare event data to submit with api
 * @param {Object} state Context state object
 * @returns {Object} Event object
 */
export const getEventData = (state) => {

  const event = {
    post_author: state.author_id,
    post_type: "etn",
    post_title: state.post_title || "",
    post_content: state.post_content || "",
    _thumbnail_id: state.etn_feature_image_id,
    etn_event_schedule: state.etn_event_schedule_ids || [],
    etn_category: state.etn_category_ids || [],
    etn_tags: state.etn_tags_ids || [],
    etn_event_organizer: state.etn_event_organizer || "",
    etn_event_socials: state.etn_event_socials || [],
    etn_event_logo: state.etn_event_logo_id || "",
    etn_event_location: state.etn_event_location || "",
    // joining_link: state.joining_link || "",
    // etn_is_virtual: state.etn_is_virtual || "",
    event_timezone: state.event_timezone || "America/New_York",
    etn_start_time: state.etn_start_time || "",
    etn_end_time: state.etn_end_time || "",
    etn_start_date: state.etn_start_date || "",
    etn_end_date: state.etn_end_date || "",
    recurring_enabled: "off",
    etn_event_recurrence: null,
    etn_ticket_availability: state?.etn_ticket_availability,
    etn_ticket_variations: state.etn_ticket_variations || [],
    banner_bg_image: state.etn_banner_bg_image_id || "",
    _etn_buddy_group_id: getDataAttrForBuddyBoss() || "",
  };
  return event;
};

/**
 * Handler for open Notification(alert) antd
 * @param {function} notification notification function of antd
 * @param {String} type Type of notification(info, warning, error etc)
 * @param {String} heading Header of the notification
 * @param {String} msg message of the notification
 */
export function openNotification(notification, type, heading, msg) {
  notification[type]({
    message: heading,
    description: msg,
  });
}

/**
 * Handler for set event form to ready for edit the event.
 * @param {Function} onChangeFormData A function that dispath to context api
 * @param {Object} data event data got from api
 * @param {Object} state context api's data object
 */
export function settingEventAllProp(onChangeFormData, data, state) {
  onChangeFormData("post_title", data.post_title);
  onChangeFormData("post_title_error", "");
  onChangeFormData("post_content", data.post_content);
  onChangeFormData("post_content_error", "");
  onChangeFormData("etn_event_logo", data.etn_event_logo_url);
  onChangeFormData("etn_event_logo_id", data.etn_event_logo);
  onChangeFormData("etn_feature_image", data._thumbnail_id_url);
  onChangeFormData("etn_feature_image_id", data._thumbnail_id);
  onChangeFormData("etn_banner_bg_image", data.banner_bg_image_url);
  onChangeFormData("etn_banner_bg_image_id", data.banner_bg_image);
  onChangeFormData("etn_start_date", data.etn_start_date);
  onChangeFormData("etn_end_date", data.etn_end_date);
  onChangeFormData("etn_start_time", data.etn_start_time);
  onChangeFormData("etn_end_time", data.etn_end_time);
  onChangeFormData("event_timezone", data.event_timezone);
  onChangeFormData("etn_event_location", data.etn_event_location);
  // onChangeFormData("joining_link", data.joining_link);
  // onChangeFormData("etn_is_virtual", data.etn_is_virtual);
  onChangeFormData(
    "etn_event_socials",
    data.etn_event_socials || etn_speaker_socials
  );
  onChangeFormData("etn_ticket_availability", data.etn_ticket_availability);
  onChangeFormData(
    "etn_ticket_variations",
    data.etn_ticket_variations || etn_ticket_variations
  );

  onChangeFormData(
    "etn_category",
    getCategories(data.selected_etn_category, state)
  );
  onChangeFormData("etn_tags", getTags(data.selected_etn_tags, state));
  onChangeFormData("etn_category_ids", data.selected_etn_category);
  onChangeFormData("etn_tags_ids", data.selected_etn_tags);

  onChangeFormData("etn_event_organizer", data.etn_event_organizer);
  onChangeFormData(
    "etn_event_schedule",
    getScheduleData(data.etn_event_schedule, state)
  );
  // onChangeFormData();
}

/**
 * A hepler function to prepare tags data for event form
 * @param {Array} _tags List of tags of specific event available through api.
 * @param {Object} st Context api state object
 * @returns Array of tags formatted as event form demands.
 */
function getTags(_tags, st) {
  const { tags } = st;

  const _t = [..._tags].map((tag) => [...tags].filter((t) => t.term_id == tag));
  var merged = [].concat.apply([], _t);
  const _merged = [...merged].map((m) => {
    return {
      label: m.name,
      value: m.term_id,
      key: m.term_id,
      disabled: undefined,
    };
  });
  return _merged;
}

/**
 * A hepler function to prepare categories data for event form
 * @param {Array} _categories List of categories of specific event available through api.
 * @param {Objec} st Context api state object
 * @returns Array of categories formatted as event form demands.
 */
function getCategories(_categories, st) {
  const { categories } = st;
  const _c = [..._categories].map((cat) =>
    [...categories].filter((c) => c.term_id == cat)
  );
  var merged = [].concat.apply([], _c);
  const _merged = [...merged].map((m) => {
    return {
      label: m.name,
      value: m.term_id,
      key: m.term_id,
      disabled: undefined,
    };
  });
  return _merged;
}


/**
 * A hepler function to prepare schedule data for event form
 * @param {Array} _schedule List of schedules of specific event available through api.
 * @param {Object} st Context api state object
 * @returns Array of schedules formatted as event form demands.
 */
function getScheduleData(_schedule, st) {
  const { schedules } = st;
  const _c = [..._schedule].map((cat) =>
    [...schedules].filter((c) => c.ID == cat)
  );
  var merged = [].concat.apply([], _c);
  const _merged = [...merged].map((m) => {
    return { label: m.post_name, value: m.ID, key: m.ID, disabled: undefined };
  });
  return _merged;
}

/**
 * Handler for reset event form data
 * 
 * @param {Function} onChangeFormData A function that dispath to context api
 */
export function removeEventDataFromEditMode(onChangeFormData) {
  onChangeFormData("eventData", null);
  onChangeFormData("post_title", "");
  onChangeFormData("post_title_error", "Post title is required!");
  onChangeFormData("post_content", "");
  onChangeFormData("post_content_error", "Post content is required!");
  onChangeFormData("etn_event_logo", "");
  onChangeFormData("etn_event_logo_id", "");
  onChangeFormData("etn_feature_image", "");
  onChangeFormData("etn_feature_image_id", "");
  onChangeFormData("etn_banner_bg_image", "");
  onChangeFormData("etn_banner_bg_image_id", "");
  onChangeFormData("etn_start_date", "");
  onChangeFormData("etn_end_date", "");
  onChangeFormData("etn_start_time", "");
  onChangeFormData("etn_end_time", "");
  onChangeFormData("event_timezone", "");
  onChangeFormData("etn_event_location", "");

  onChangeFormData("etn_event_socials", [
    {
      icon: "",
      etn_social_title: "",
      etn_social_url: "",
    },
  ]);
  onChangeFormData("etn_ticket_availability", false);
  onChangeFormData("etn_ticket_variations", [
    {
      etn_ticket_name: "",
      etn_ticket_price: "",
      etn_avaiilable_tickets: "",
      etn_min_ticket: "",
      etn_max_ticket: "",
    },
  ]);

  onChangeFormData("etn_category", []);
  onChangeFormData("etn_tags", []);
  onChangeFormData("etn_category_ids", null);
  onChangeFormData("etn_tags_ids", null);

  onChangeFormData("etn_event_organizer", [
    {
      name: "",
      description: "",
    },
  ]);
  onChangeFormData("etn_event_schedule", [
    {
      title: "",
      topic: "",
      start_time: "",
      end_time: "",
    },
  ]);
  // onChangeFormData();
}

/**
 * Get Form data from any js object.
 * 
 * @param {Object} data
 * @returns JS FormData object
 */
export const getFormData = (data) => {
  let formData = new FormData();

  for (let dataKey in data) {
    if (dataKey === "category") {
      formData.append("category", [...data[dataKey]].toString());
    }
    if (dataKey === "social") {
      // append nested object
      for (let socialKey in data[dataKey]) {
        formData.append(`social[${socialKey}]`, data[dataKey][socialKey]);
      }
    } else {
      formData.append(dataKey, data[dataKey]);
    }
  }

  return formData;
};

/**
 * Helper function for prepare speaker list to Context api
 * 
 * @param {Object} Object {speaker id(if we are tring to update), speaker list, current created/update speaker} 
 * @returns Array of Speakers
 */
export const prepareSpeakerDataForContext = ({ id, speakers, data }) => {
  let _speakers = [...speakers];
  if (!data.id) return _speakers;
  if (id) {
    const index = _speakers.findIndex(item => item.id == id);
    if(index != -1){
      _speakers[index] = data
    }
  } else {
    _speakers = [..._speakers, data].reverse();
  }

  return _speakers;
};


/**
 * Helper function to prepare events list to Context api
 * 
 * @param {Object} Object {List of events, current created/update event} 
 * @returns Array of events
 */
export const prepareEventDataForContext = ({ events, event }) => {
  let _events = [...events];
  if (event.id) {
    const index = _events.findIndex(item => item.id == event.id);
    if(index != -1){
      _events[index] = event
    }else{
      _events = [event,..._events ]
    }
  }

  return _events;
};


