import { Button, Col, Dropdown, Menu, notification, Pagination, Result, Row, Space, Table, Tooltip } from "antd";
import { EditOutlined, ScanOutlined } from '@ant-design/icons';
import React, { useState, useContext, useEffect } from "react";
import EventContext from "../context/EventContext";
import Header from "../components/common/Header";
import Wrapper from "../components/Wrapper";
import { base_url, delete_event, event_lists } from "../apiEndpoints/endPoints";
import { openNotification, removeEventDataFromEditMode, settingEventAllProp } from "../helpers/helper";
import DeleteConfirm from "../components/common/DeleteConfirm";
import Spinner from "../components/common/Spinner";
import { SmileOutlined } from '@ant-design/icons';
import TopNavigation from "../components/common/TopNavigation";
import { useNavigate } from "react-router-dom";
const { __ } = wp.i18n;

function Events() {
  const navigate = useNavigate()
  const { state, onChangeFormData, onEventDeleteHandler } = useContext(EventContext);
  const [eventToDelete, setEventToDelete] = useState(null);
  const [loading, setLoading] = useState(false);

  const { isLoading, total_pages, events_count, events, paged,
    posts_per_page, component} = state;
  // const [component, setComponent] = useState("table");
  const [editMode, setEditMode] = useState(false);
  const [eventId, setEventId] = useState(null);

  /**
   * 
   * @param {Object} Object An Object consist of a key from options of single event(... option)
   */
  const onClick = ({ key }) => {
    const currentUrl = window.location.href;
    const isDashboard = currentUrl.includes('/dashboard')
    if (key == 'preview') {

    }
    if (key == 'attendees') {
      onChangeFormData('top_nav_menu_active', key)
      onChangeFormData('paged', 1)
      onChangeFormData('clicked_event', eventToDelete)
      onChangeFormData('component', 'attendees')
      const url = isDashboard ? `/attendees?event=${eventToDelete?.id}` :  `/attendees?event=${eventToDelete?.id}`;
      navigate(url)
    }
    if (key == 'delete_event') {
      //delete event.
      onChangeFormData('show_delete_modal', true)

    }

  };

 /**
   * An Array consist of List of menu for options of single event(... option)
   */
  const menu = (
    <Menu
      onClick={onClick}
      className={'etn-frontend-action-dropdown'}
      items={[
        {
          key: 'preview',
          label: <a href={eventToDelete?.permalink} target={'_blank'}> {__("Preview", "eventin-pro")}</a>,
        },
        {
          key: 'attendees',
          label:  __("Attendee list", "eventin-pro"),
        },
        {
          key: 'delete_event',
          label:  __("Delete", "eventin-pro"),
          className: 'etn-item-delete-style'
        },
      ]}
    />
  );

  /**
   * Handler for GET events from BACKEND using API 
   * @param {Number} pageNo Current page number
   * @param {Number} perPage Number of data per page
   */
  const fetchEvents = (pageNo, perPage) => {
    const user_id = localized_data_obj.author_id;
    const _perPage = perPage ? perPage : posts_per_page;
    const _pageNo = pageNo ? pageNo : paged;
    onChangeFormData('paged', _pageNo)
    setLoading(true);
    fetch(`${event_lists}?user_id=${user_id}&posts_per_page=${_perPage}&paged=${_pageNo}`)
      .then((res) => res.json())
      .then(
        (result) => {
          onChangeFormData('events', result.items)
          onChangeFormData('events_count', result.total_items)
          onChangeFormData('total_pages', result.total_pages)
          setLoading(false);
        },
        (error) => {
          console.log("err", error);
          setLoading(false);
        }
      );
  }


  useEffect(async () => {
    onChangeFormData("component", "table");
    fetchEvents();
  }, []);

  /**
   * Handler for Ok button click of confirm modal for DELETE
   */
  const handleOk = async () => {
    const id = eventToDelete.id;
    fetch(`${delete_event}/?ids=${id}`, {
      method: "DELETE",
    }).then(async (res) => {
      const _res = await res.json();
      handleResponse(_res);
    })
      .catch((err) => {
        onChangeFormData("show_delete_modal", false);
        openNotification(
          notification,
          "error",
          __("Delete!", "eventin-pro"),
          __("Something went wrong!", "eventin-pro")
        );
      });
  };

  /**
   * Handler for process the response of DELETE event.
   * @param {Object} res Api response Object of DELETE event
   */
  const handleResponse = (res) => {
    onChangeFormData("show_delete_modal", false);
    if (res?.status_code == 200) {
      const _events = [...events].filter(
        (event) => event?.id !== eventToDelete?.id
      );
      onChangeFormData('events', _events);
      openNotification(
        notification,
        "success",
        __("Deleted!", "eventin-pro"),
        __(res?.messages?.success, "eventin-pro")
      );
    } else {
      openNotification(
        notification,
        "error",
        __("Delete!", "eventin-pro"),
        __(res?.messages?.error, "eventin-pro")
      );
    }
  };

  /**
   * Handler for hide the delete modal
   */
  const hideModal = () => {
    onChangeFormData("show_delete_modal", false);
  };

  if (loading) {
    return (<Spinner
      tip={__("Loading...", 'eventin-pro')}
      msg={__("Please Wait.", 'eventin-pro')}
      desc={__("Loader will vanish after all data load.", 'eventin-pro')}
      type={"info"}
      size={"large"}
      wrapperClassName={"ent-mltv-spinner-wrapper"}
    />)
  }

  return (
    <>
    
      <DeleteConfirm
        handleOk={handleOk}
        hideModal={hideModal}
        okText={"Delete"}
        cancelText={"Cancel"}
        title={"Are you sure you want to delete this item?"}
        icon={false}
      />
      <Row gutter={[8, 20]} style={{ marginTop: "20px" }}>
        <Col span={24}>
        <TopNavigation />  
        </Col>
        <Col span={24}>

          {component == "event" ? (
            <Button
              type="primary"
              className="etn-frontend-add-event-btn"
              onClick={() => {
                removeEventDataFromEditMode(onChangeFormData);
                setEditMode(false)
                setEventId(null)
                onChangeFormData("component", "table");
              }}
            >
              {__("Back to events", "eventin-pro")}
            </Button>
          ) : (
            <Button
              type="primary"
              className="etn-frontend-add-event-btn"
              onClick={() => {
                onChangeFormData("component", "event");
              }}
            >
             {__("Add new event", "eventin-pro")}
            </Button>
          )}
        </Col>

         {/* Condition for show the event list */}
        {component == "table" && (
          <Col span={24}>

            <div className="etn-frontend-event-list-wrapper">
              {events?.map((event) => (
                <div className="etn-frontend-event-item" key={event?.id}>
                  <div className="etn-frontend-event-data">
                    {event?.image &&
                      <div className="etn-frontend-event-image">
                        <img onClick={() => {
                          onChangeFormData("component", "event");
                          setEditMode(true)
                          setEventId(event?.id)
                          }} src={event?.image} alt="Event thumbnail" />
                      </div>
                    }
                    <div className="etn-frontend-event-content">
                      <h3 className="etn-frontend-event-title" onClick={() => {
                        onChangeFormData("component", "event");
                        setEditMode(true)
                        setEventId(event?.id)
                        }}>{event?.title}</h3>
                      <ul className="etn-frontend-event-meta-list">
                        {event?.date &&
                          <li>
                            <svg width="15" height="16" viewBox="0 0 15 16" fill="none" xmlns="http://www.w3.org/2000/svg">
                              <path d="M4.5 1V3.1" stroke="#292D32" strokeWidth="1.3" strokeMiterlimit="10" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M10.0996 1V3.1" stroke="#292D32" strokeWidth="1.3" strokeMiterlimit="10" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M1.34961 5.96289H13.2496" stroke="#292D32" strokeWidth="1.3" strokeMiterlimit="10" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M13.6 5.5498V11.4998C13.6 13.5998 12.55 14.9998 10.1 14.9998H4.5C2.05 14.9998 1 13.5998 1 11.4998V5.5498C1 3.4498 2.05 2.0498 4.5 2.0498H10.1C12.55 2.0498 13.6 3.4498 13.6 5.5498Z" stroke="#292D32" strokeWidth="1.3" strokeMiterlimit="10" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M7.29733 9.18984H7.30361" stroke="#292D32" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M4.70553 9.18984H4.71182" stroke="#292D32" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round" />
                              <path d="M4.70553 11.2895H4.71182" stroke="#292D32" strokeWidth="1.5" strokeLinecap="round" strokeLinejoin="round" />
                            </svg>
                            {event?.date}
                          </li>
                        }
                        {event?.location &&
                          <li>
                            <svg width="14" height="16" viewBox="0 0 14 16" fill="none" xmlns="http://www.w3.org/2000/svg">
                              <path d="M7.03806 9.00288C8.24455 9.00288 9.22261 8.02483 9.22261 6.81834C9.22261 5.61184 8.24455 4.63379 7.03806 4.63379C5.83157 4.63379 4.85352 5.61184 4.85352 6.81834C4.85352 8.02483 5.83157 9.00288 7.03806 9.00288Z" stroke="#292D32" strokeWidth="1.5" />
                              <path d="M1.16997 5.54414C2.54932 -0.519378 11.5326 -0.512376 12.9049 5.55114C13.7101 9.10803 11.4976 12.1188 9.55807 13.9812C8.15072 15.3396 5.92416 15.3396 4.50981 13.9812C2.57732 12.1188 0.36477 9.10103 1.16997 5.54414Z" stroke="#292D32" strokeWidth="1.5" />
                            </svg>
                            {event?.location}
                          </li>
                        }
                      </ul>
                    </div>
                  </div>
                  <div className="etn-frontend-event-action">
                    <Button
                      type="default"
                      className="etn-frontend-event-edit-button"
                      onClick={() => {

                        onChangeFormData("component", "event");
                        setEditMode(true)
                        setEventId(event?.id)
                      }}
                    >
                      <EditOutlined />
                      {__("Edit", "eventin-pro")}
                    </Button>
                    <Tooltip placement="topLeft" title={event?.booked_seats > 0 ? "" : __("This event doesn't have any attendee", "eventin-pro")}>
                    <Button
                      type="default"
                      className="etn-front-end-ticket-scanner  etn-frontend-action-item"
                      onClick={() => {
                        window.location.href =`${base_url}/wp-admin/edit.php?post_type=etn-attendee&etn_action=ticket_scanner&from=frontend&event_id=${event?.id}`                        
                      }}
                      disabled={event?.booked_seats > 0 ? false : true}
                      style={event?.booked_seats > 0 ? {} : {color: '#00000040', backgroundColor: '#f5f5f5', borderColor: '#d9d9d9', marginRight: '15px'}}
                    >
                      <ScanOutlined />
                      {__("Ticket Scanner", "eventin-pro")}
                    </Button>
                    </Tooltip>
                    <Dropdown overlay={menu} placement="bottom" trigger={["click"]}>
                      <Button className="etn-fend-dropdown-trigger" onClick={() => { setEventToDelete(event) }}>...</Button>
                    </Dropdown>
                  </div>
                </div>
              ))}
              {events?.length ? <Pagination
                total={events_count}
                defaultPageSize={posts_per_page}
                showSizeChanger={true}
                defaultCurrent={paged}
                pageSizeOptions={["20", "50", "100"]}
                className={'etn-ant-pagination'}
                onChange={(pageNo, perPage) => {
                  fetchEvents(pageNo, perPage);
                }}

                onShowSizeChange={(current, size) => {
                  onChangeFormData('posts_per_page', size)
                  onChangeFormData('paged', current)
                }}
              /> : null}
              {!events?.length && <Result
                icon={<SmileOutlined />}
                title={__("Ops! You haven't added any events yet.", "eventin-pro")}

              />}
            </div>
          </Col>
        )}
         {/* Condition for show the event form */}
        {component == "event" && (
          <Col span={24}>
            <Header />
            <Wrapper event_id={eventId} shouldUpdate={editMode} />
          </Col>
        )}
      </Row>
    </>
  );
}

export default Events;
