import {
  Button,
  Col,
  Dropdown,
  Form,
  Menu,
  notification,
  Pagination,
  Result,
  Row,
  Select,
  Space,
} from "antd";
import React, { useState, useContext, useEffect } from "react";
import CreateSpeaker from "../components/common/CreateSpeaker";
import TopNavigation from "../components/common/TopNavigation";
import EventContext from "../context/EventContext";
import PlusSvg from "../components/common/PlusSvg";
import { PlusOutlined } from "@ant-design/icons";
import DeleteConfirm from "../components/common/DeleteConfirm";
import { delete_event, speakers_api } from "../apiEndpoints/endPoints";
import {
  openNotification,
  removeEventDataFromEditMode,
} from "../helpers/helper";
import { EditOutlined, SmileOutlined } from "@ant-design/icons";
import Spinner from "../components/common/Spinner";
import {
  etn_speaker_create,
  etn_speaker_socials as socials,
} from "../stores/store";

const { __ } = wp.i18n;

function Speakers() {
  const { state, onChangeFormData } = useContext(EventContext);
  const {
    speakers_count,
    speakers,
    isLoading,
    etn_event_speaker,
    etn_event_speaker_create,
    etn_event_organizer_create,
    organizerData,
    component,
    paged,
    posts_per_page,
  } = state;
  const [selectOpen, setOpen] = useState(false);
  const [editMode, setEditMode] = useState(false);
  const [speakerToDelete, setspeakerToDelete] = useState(null);
  const [speakerId, setSpeakerId] = useState(null);

  /**
   *
   * @param {Object} Object An Object consist of a key from options of single speaker(... option)
   */
  const onClick = ({ key }) => {
    if (key == "delete_event") {
      //delete event.
      onChangeFormData("show_delete_modal", true);
    }
    if (key == "preview_event") {
      //preview_event.
    }
  };

  /**
   * An Array consist of List of menu for options of single speaker(... option)
   */
  const menu = (
    <Menu
      onClick={onClick}
      className={"etn-frontend-action-dropdown"}
      items={[
        {
          key: "preview_event",
          label: (
            <a href={speakerToDelete?.perma_link} target={"_blank"}>
              {" "}
              {__("Preview", "eventin-pro")}
            </a>
          ),
          className: "etn-item-preview-style",
        },
        {
          key: "delete_event",
          label: __("Delete", "eventin-pro"),
          className: "etn-item-delete-style",
        },
      ]}
    />
  );

  /**
   * Handler for GET speakers from BACKEND using API
   * @param {Number} pageNo Current page number
   * @param {Number} perPage Number of data per page
   */
  const fetchSpeakers = (pageNo, perPage) => {
    const user_id = localized_data_obj.author_id;
    const _perPage = perPage ? perPage : posts_per_page;
    const _pageNo = pageNo ? pageNo : paged;
    onChangeFormData("isLoading", true);
    onChangeFormData("paged", _pageNo);
    fetch(
      `${speakers_api}?user_id=${user_id}&posts_per_page=${_perPage}&paged=${_pageNo}`
    )
      .then((res) => res.json())
      .then(
        (result) => {
          onChangeFormData("speakers", result.items);
          onChangeFormData("speakers_count", result.total_items);
          onChangeFormData("total_pages", result.total_pages);
          onChangeFormData("isLoading", false);
        },
        (error) => {
          console.log("err", error);
          onChangeFormData("isLoading", false);
        }
      );
  };

  useEffect(async () => {
    onChangeFormData("component", "table");
    fetchSpeakers();
  }, []);

  /**
   * Handler for Ok button click of confirm modal for DELETE
   */
  const handleOk = async () => {
    const id = speakerToDelete.id;
    fetch(`${speakers_api}/?ids=${id}`, {
      method: "DELETE",
    })
      .then(async (res) => {
        const _res = await res.json();
        handleResponse(_res);
      })
      .catch((err) => {
        onChangeFormData("show_delete_modal", false);
        openNotification(
          notification,
          "error",
          __("Delete!", "eventin-pro"),
          __("Something went wrong!", "eventin-pro")
        );
      });
  };

  /**
   * Handler for process the response of DELETE speaker.
   * @param {Object} res Api response Object of DELETE event
   */
  const handleResponse = (res) => {
    onChangeFormData("show_delete_modal", false);
    if (res?.status_code == 200) {
      const _speakers = [...speakers].filter(
        (speaker) => speaker?.id !== speakerToDelete?.id
      );
      onChangeFormData("speakers", _speakers);
      openNotification(
        notification,
        "success",
        __("Deleted!", "eventin-pro"),
        __(res?.messages?.success, "eventin-pro")
      );
    } else {
      openNotification(
        notification,
        "error",
        __("Delete!", "eventin-pro"),
        __(res?.messages?.error, "eventin-pro")
      );
    }
  };

  /**
   * Handler for hide the delete modal
   */
  const hideModal = () => {
    onChangeFormData("show_delete_modal", false);
  };

  if (isLoading) {
    return (
      <Spinner
        tip={__("Loading...", "eventin-pro")}
        msg={__("Please Wait.", "eventin-pro")}
        desc={__("Loader will vanish after all data load.", "eventin-pro")}
        type={"info"}
        size={"large"}
        wrapperClassName={"ent-mltv-spinner-wrapper"}
      />
    );
  }

  return (
    <div className="etn-mltv-general-info">
      <DeleteConfirm
        handleOk={handleOk}
        hideModal={hideModal}
        okText={"Delete"}
        cancelText={"Cancel"}
        title={"Are you sure you want to delete this item?"}
        icon={false}
      />
      <Row gutter={[8, 20]} style={{ marginTop: "20px" }}>
        <Col span={24}>
          <TopNavigation />
        </Col>
        <Col span={24}>
          {component == "speaker" ? (
            <Button
              type="primary"
              className="etn-frontend-add-event-btn"
              onClick={() => {
                removeEventDataFromEditMode(onChangeFormData);
                setEditMode(false);
                setSpeakerId(null);
                onChangeFormData("component", "table");
                onChangeFormData("etn_speaker_create", etn_speaker_create);
              }}
            >
              {__("Back to speakers", "eventin-pro")}
            </Button>
          ) : (
            <Button
              type="primary"
              className="etn-frontend-add-event-btn"
              onClick={() => {
                onChangeFormData("component", "speaker");
              }}
            >
              {__("Add new speaker", "eventin-pro")}
            </Button>
          )}
        </Col>
        <Col xs={24} sm={24} md={24}>
          {component == "table" && (
            <Col span={24}>
              <div className="etn-frontend-event-list-wrapper">
                {speakers?.map((speaker) => (
                  <div className="etn-frontend-event-item" key={speaker?.id}>
                    <div className="etn-frontend-event-data">
                      {speaker?.image && (
                        <div className="etn-frontend-event-image">
                          <img
                            onClick={() => {
                              onChangeFormData("component", "speaker");
                              setEditMode(true);
                              setSpeakerId(speaker?.id);
                              const _speaker =
                                replaceSocialsWithDefault(speaker);
                              onChangeFormData("etn_speaker_create", _speaker);
                            }}
                            src={speaker?.image}
                            alt="Speaker thumbnail"
                          />
                        </div>
                      )}
                      <div className="etn-frontend-event-content">
                        <h3
                          className="etn-frontend-event-title"
                          onClick={() => {
                            onChangeFormData("component", "speaker");
                            const _speaker = replaceSocialsWithDefault(speaker);
                            setEditMode(true);
                            setSpeakerId(speaker?.id);
                            onChangeFormData("etn_speaker_create", _speaker);
                          }}
                        >
                          {speaker?.name}
                        </h3>
                       {speaker?.designation &&  <p style={{margin: '0', fontSize: '14px', fontWeight: '400'}}>{speaker?.designation}</p>}
                        <ul className="etn-frontend-event-meta-list">
                          {speaker?.post_date && (
                            <li>
                              <svg
                                width="15"
                                height="16"
                                viewBox="0 0 15 16"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                              >
                                <path
                                  d="M4.5 1V3.1"
                                  stroke="#292D32"
                                  strokeWidth="1.3"
                                  strokeMiterlimit="10"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M10.0996 1V3.1"
                                  stroke="#292D32"
                                  strokeWidth="1.3"
                                  strokeMiterlimit="10"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M1.34961 5.96289H13.2496"
                                  stroke="#292D32"
                                  strokeWidth="1.3"
                                  strokeMiterlimit="10"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M13.6 5.5498V11.4998C13.6 13.5998 12.55 14.9998 10.1 14.9998H4.5C2.05 14.9998 1 13.5998 1 11.4998V5.5498C1 3.4498 2.05 2.0498 4.5 2.0498H10.1C12.55 2.0498 13.6 3.4498 13.6 5.5498Z"
                                  stroke="#292D32"
                                  strokeWidth="1.3"
                                  strokeMiterlimit="10"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M7.29733 9.18984H7.30361"
                                  stroke="#292D32"
                                  strokeWidth="1.5"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M4.70553 9.18984H4.71182"
                                  stroke="#292D32"
                                  strokeWidth="1.5"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                                <path
                                  d="M4.70553 11.2895H4.71182"
                                  stroke="#292D32"
                                  strokeWidth="1.5"
                                  strokeLinecap="round"
                                  strokeLinejoin="round"
                                />
                              </svg>
                              {speaker?.post_date}
                            </li>
                          )}
                          {speaker?.location && (
                            <li>
                              <svg
                                width="14"
                                height="16"
                                viewBox="0 0 14 16"
                                fill="none"
                                xmlns="http://www.w3.org/2000/svg"
                              >
                                <path
                                  d="M7.03806 9.00288C8.24455 9.00288 9.22261 8.02483 9.22261 6.81834C9.22261 5.61184 8.24455 4.63379 7.03806 4.63379C5.83157 4.63379 4.85352 5.61184 4.85352 6.81834C4.85352 8.02483 5.83157 9.00288 7.03806 9.00288Z"
                                  stroke="#292D32"
                                  strokeWidth="1.5"
                                />
                                <path
                                  d="M1.16997 5.54414C2.54932 -0.519378 11.5326 -0.512376 12.9049 5.55114C13.7101 9.10803 11.4976 12.1188 9.55807 13.9812C8.15072 15.3396 5.92416 15.3396 4.50981 13.9812C2.57732 12.1188 0.36477 9.10103 1.16997 5.54414Z"
                                  stroke="#292D32"
                                  strokeWidth="1.5"
                                />
                              </svg>
                              {speaker?.location}
                            </li>
                          )}
                        </ul>
                      </div>
                    </div>
                    <div className="etn-frontend-event-action">
                      <Button
                        type="default"
                        className="etn-frontend-event-edit-button"
                        onClick={() => {
                          onChangeFormData("component", "speaker");
                          setEditMode(true);
                          setSpeakerId(speaker?.id);
                          const _speaker = replaceSocialsWithDefault(speaker);
                          onChangeFormData("etn_speaker_create", _speaker);
                        }}
                      >
                        <EditOutlined />
                        {__("Edit", "eventin-pro")}
                      </Button>
                      <Dropdown
                        overlay={menu}
                        placement="bottom"
                        trigger={["click"]}
                      >
                        <Button
                          className="etn-fend-dropdown-trigger"
                          onClick={() => {
                            setspeakerToDelete(speaker);
                          }}
                        >
                          ...
                        </Button>
                      </Dropdown>
                    </div>
                  </div>
                ))}
                {speakers?.length ? (
                  <Pagination
                    total={speakers_count}
                    defaultPageSize={posts_per_page}
                    showSizeChanger={true}
                    defaultCurrent={paged}
                    pageSizeOptions={["20", "50", "100"]}
                    className={"etn-ant-pagination"}
                    onChange={(pageNo, perPage) => {
                      fetchSpeakers(pageNo, perPage);
                    }}
                    onShowSizeChange={(current, size) => {
                      onChangeFormData("posts_per_page", size);
                      onChangeFormData("paged", current);
                    }}
                  />
                ) : null}
                {!speakers?.length && (
                  <Result
                    icon={<SmileOutlined />}
                    title={__(
                      "Oops! You haven't added any speakers yet.",
                      "eventin-pro"
                    )}
                  />
                )}
              </div>
            </Col>
          )}
          {component == "speaker" && (
            <Col span={24}>
              <CreateSpeaker editMode={editMode} id={speakerId} />
            </Col>
          )}
        </Col>
      </Row>
    </div>
  );
}

export default Speakers;

export const replaceSocialsWithDefault = (data) => {
  let _data = data;
  if (!Array.isArray(data?.socials)) {
    _data = { ...data, socials: socials };
  }

  return _data;
};
