import React, { useReducer } from "react";

import EventContext from "../context/EventContext";
import reducer from "../reducers/eventReducer";
import initialState from "../stores/store";
import actions from "../actions/eventAction";
import {
  get_attendees_by_event_id,
  update_attendee_by_id,
  update_ticket_status,
} from "../apiEndpoints/endPoints";
import { attendeeUpdateHandler, createSpeakerCatHandler, createSpeakerHandler, eventDeleteHandler, pageChangeHandler, ticketStatusHandler } from "../helpers/actions";

const EventContextProvider = (props) => {
  const [state, dispatch] = useReducer(reducer, initialState);

  const value = {
    contacts: state.contacts,
    state: state,
    nextStep: (value) => {
      dispatch({ type: actions.NEXT_STEP, value });
    },
    setCategoryData: (value) => {
      dispatch({ type: actions.SET_CATEGORY_DATA, value });
    },
    setTagsData: (value) => {
      dispatch({ type: actions.SET_TAGS_DATA, value });
    },
    setScheduleData: (value) => {
      dispatch({ type: actions.SET_SCHEDULE_DATA, value });
    },
    setOrganizerData: (value) => {
      dispatch({ type: actions.SET_ORGANIZER_DATA, value });
    },
    setTimeZoneData: (value) => {
      dispatch({ type: actions.SET_TIME_ZONE_DATA, value });
    },
    onChangeFormData: (name, value) => {
      dispatch({ type: actions.ON_CHANGE_FORM_DATA, name, value });
    },
    setSocialLinks: (value) => {
      dispatch({ type: actions.SET_SOCIAL_LINKS, value });
    },
    setEventData: (value) => {
      dispatch({ type: actions.SET_EVENT_DATA, value });
    },
    onPageChangeHandler: async ({ event_id, page_no, posts_per_page }) => {
      pageChangeHandler({ event_id, page_no, posts_per_page }, dispatch,
        state)
    },
    onTicketStatusChangeHandler: async ({ attendee, ticket, status, attendeeData }) => {
      ticketStatusHandler({ attendee, ticket, status, attendeeData }, dispatch,
        state)
      // const {content: attendees, count} = data;
     
    },
    onAttendeeUpdateHandler: (attendee) => {
      attendeeUpdateHandler(attendee, dispatch, state);
    },
    onEventDeleteHandler: (event) => {
      eventDeleteHandler(event, dispatch, state);
    },
    onCreateSpeaker: (speaker, id = null) => {
      createSpeakerHandler(speaker,id, dispatch, state);
    },
    onCreateSpeakerCat: (speaker_cat) => {
      createSpeakerCatHandler(speaker_cat, dispatch, state);
    },
  };

  return (
    <EventContext.Provider value={value}>
      {props.children}
    </EventContext.Provider>
  );
};

export default EventContextProvider;




